---
title: Area
sidebar: mydoc_sidebar
keywords: area, stack
permalink: /area
---

## Method Signatures
{% highlight julia %}
#Array methods
area(x::AbstractVector, y::AbstractVector{<:Union{Missing, Real}})
area(x::AbstractVector, y::AbstractArray{<:Union{Missing, Real},2})

#Dataframe methods
area(df::AbstractDataFrame, x::Symbol, y::Symbol)
area(df::AbstractDataFrame, x::Symbol, y::Symbol, group::Symbol)

#Other methods
area(k::KernelDensity.UnivariateKDE)

{% endhighlight %}

## Optional Arguments
{% highlight julia %}
mark::Union{String, AbstractVector} = "line"
fill::Union{Bool, AbstractVector} = true
stack::Union{Bool, AbstractVector, Void} = true
step::Union{String, Void} = nothing #choice of {"start", "middle", "end"}
legend::Bool = false
scale::Bool = false
kwargs... #modifies top-level EChart properties
{% endhighlight %}

## Examples

### Single Series
{% highlight julia %}
using ECharts
x = ["Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"]
y = [11, 11, 15, 13, 12, 13, 10]
ar = area(x, y)
{% endhighlight %}

<div id="areaplot" style="height:400px;width:800px;"></div>
<script type="text/javascript">

    // Initialize after dom ready
    var myChart = echarts.init(document.getElementById("areaplot"), JSON.parse(roma()));

    // Load data into the ECharts instance
    myChart.setOption(
        {"xAxis":[{"splitNumber":5,"boundaryGap":false,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"data":["Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"],"scale":false,"gridIndex":0,"minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":30,"silent":true,"type":"category"}],"ec_charttype":"xy plot","series":[{"name":"Series 1","yAxisIndex":0,"areaStyle":{},"xAxisIndex":0,"smooth":false,"data":[11,11,15,13,12,13,10],"markLine":{"data":[],"lineStyle":{}},"type":"line"}],"theme":{"geo":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"parallel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"markPoint":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}},"emphasis":{"textStyle":{"color":"#eeeeee"}}}},"visualMap":{"color":["#e01f54","#e7dbc3"]},"funnel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"bar":{"itemStyle":{"normal":{"barBorderColor":"#ccc","barBorderWidth":0},"emphasis":{"barBorderColor":"#ccc","barBorderWidth":0}}},"map":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"scatter":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"pie":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"graph":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}}},"symbolSize":4,"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"}},"smooth":false,"symbol":"emptyCircle","color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"lineStyle":{"normal":{"color":"#aaaaaa","width":1}}},"backgroundColor":"rgba(0,0,0,0)","line":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"candlestick":{"itemStyle":{"normal":{"borderColor0":"#b8d2c7","color":"#e01f54","borderColor":"#f5e8c8","borderWidth":1,"color0":"#001852"}}},"sankey":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"valueAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"toolbox":{"iconStyle":{"normal":{"borderColor":"#999999"},"emphasis":{"borderColor":"#666666"}}},"categoryAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"tooltip":{"axisPointer":{"crossStyle":{"color":"#cccccc","width":1},"lineStyle":{"color":"#cccccc","width":1}}},"timeline":{"label":{"normal":{"textStyle":{"color":"#293c55"}},"emphasis":{"textStyle":{"color":"#293c55"}}},"controlStyle":{"normal":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5},"emphasis":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5}},"checkpointStyle":{"color":"#e43c59","borderColor":"rgba(194,53,49,0.5)"},"itemStyle":{"normal":{"color":"#293c55","borderWidth":1},"emphasis":{"color":"#a9334c"}},"lineStyle":{"color":"#293c55","width":1}},"radar":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"logAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"textStyle":{},"gauge":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"boxplot":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"title":{"textStyle":{"color":"#333333"},"subtextStyle":{"color":"#aaaaaa"}},"dataZoom":{"dataBackgroundColor":"rgba(47,69,84,0.3)","textStyle":{"color":"#333333"},"handleSize":"100%","handleColor":"#a7b7cc","fillerColor":"rgba(167,183,204,0.4)","backgroundColor":"rgba(47,69,84,0)"},"timeAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"legend":{"textStyle":{"color":"#333333"}}},"yAxis":[{"splitNumber":5,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"scale":false,"gridIndex":0,"minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":50,"silent":true,"type":"value"}],"toolbox":{"feature":{},"orient":"vertical","itemSize":15,"height":"auto","zlevel":0,"z":2,"itemGap":20,"right":"auto","top":"center","width":"auto","show":false,"showTitle":true},"ec_width":800,"ec_height":400,"tooltip":{"triggerOn":"mousemove","enterable":true,"borderColor":"#333","transitionDuration":0.4,"hideDelay":100,"padding":5,"showDelay":0,"borderWidth":0,"showContent":true,"backgroundColor":"rgba(50,50,50,0.7)","trigger":"item","alwaysShowContent":false,"confine":false,"show":true},"grid":[{"height":"auto","show":false,"width":"auto","backgroundColor":"transparent"}],"title":[{"left":"left","borderColor":"transparent","bottom":"auto","padding":5,"zlevel":0,"borderWidth":1,"target":"blank","z":2,"itemGap":5,"shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","subtarget":"blank","show":true}],"ec_renderer":"canvas"}
        );
</script>

### Multiple Series (Stacked Area)

The default when passed multiple series is to _stack_ the series, i.e. showing the individual series contribution to the whole. If you want to overlay each series relative to zero on the Y-axis, use `stack = false`.

In order for the stacked charts to render properly, any `missing` values are __set to 0__ on render. If this is not the correct treatment, you need to remove `missing` values prior to calling `area()`.

{% highlight julia %}
using ECharts
x = ["Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"]
y = [11, 11, 15, 13, 12, 13, 10]
y2 = 3.7 .* y
as = area(x, hcat(y, y2))
{% endhighlight %}

<div id="areaplot2" style="height:400px;width:800px;"></div>
<script type="text/javascript">

    // Initialize after dom ready
    var myChart = echarts.init(document.getElementById("areaplot2"), JSON.parse(roma()));

    // Load data into the ECharts instance
    myChart.setOption(
        {"xAxis":[{"splitNumber":5,"boundaryGap":false,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"data":["Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"],"scale":false,"gridIndex":0,"minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":30,"silent":true,"type":"category"}],"ec_charttype":"xy plot","series":[{"name":"Series 1","yAxisIndex":0,"areaStyle":{},"xAxisIndex":0,"stack":1,"smooth":false,"data":[11.0,11.0,15.0,13.0,12.0,13.0,10.0],"markLine":{"data":[],"lineStyle":{}},"type":"line"},{"name":"Series 2","yAxisIndex":0,"areaStyle":{},"xAxisIndex":0,"stack":1,"smooth":false,"data":[40.7,40.7,55.5,48.1,44.400000000000006,48.1,37.0],"markLine":{"data":[],"lineStyle":{}},"type":"line"}],"theme":{"geo":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"parallel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"markPoint":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}},"emphasis":{"textStyle":{"color":"#eeeeee"}}}},"visualMap":{"color":["#e01f54","#e7dbc3"]},"funnel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"bar":{"itemStyle":{"normal":{"barBorderColor":"#ccc","barBorderWidth":0},"emphasis":{"barBorderColor":"#ccc","barBorderWidth":0}}},"map":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"scatter":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"pie":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"graph":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}}},"symbolSize":4,"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"}},"smooth":false,"symbol":"emptyCircle","color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"lineStyle":{"normal":{"color":"#aaaaaa","width":1}}},"backgroundColor":"rgba(0,0,0,0)","line":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"candlestick":{"itemStyle":{"normal":{"borderColor0":"#b8d2c7","color":"#e01f54","borderColor":"#f5e8c8","borderWidth":1,"color0":"#001852"}}},"sankey":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"valueAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"toolbox":{"iconStyle":{"normal":{"borderColor":"#999999"},"emphasis":{"borderColor":"#666666"}}},"categoryAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"tooltip":{"axisPointer":{"crossStyle":{"color":"#cccccc","width":1},"lineStyle":{"color":"#cccccc","width":1}}},"timeline":{"label":{"normal":{"textStyle":{"color":"#293c55"}},"emphasis":{"textStyle":{"color":"#293c55"}}},"controlStyle":{"normal":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5},"emphasis":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5}},"checkpointStyle":{"color":"#e43c59","borderColor":"rgba(194,53,49,0.5)"},"itemStyle":{"normal":{"color":"#293c55","borderWidth":1},"emphasis":{"color":"#a9334c"}},"lineStyle":{"color":"#293c55","width":1}},"radar":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"logAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"textStyle":{},"gauge":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"boxplot":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"title":{"textStyle":{"color":"#333333"},"subtextStyle":{"color":"#aaaaaa"}},"dataZoom":{"dataBackgroundColor":"rgba(47,69,84,0.3)","textStyle":{"color":"#333333"},"handleSize":"100%","handleColor":"#a7b7cc","fillerColor":"rgba(167,183,204,0.4)","backgroundColor":"rgba(47,69,84,0)"},"timeAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"legend":{"textStyle":{"color":"#333333"}}},"yAxis":[{"splitNumber":5,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"scale":false,"gridIndex":0,"minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":50,"silent":true,"type":"value"}],"toolbox":{"feature":{},"orient":"vertical","itemSize":15,"height":"auto","zlevel":0,"z":2,"itemGap":20,"right":"auto","top":"center","width":"auto","show":false,"showTitle":true},"ec_width":800,"ec_height":400,"tooltip":{"triggerOn":"mousemove","enterable":true,"borderColor":"#333","transitionDuration":0.4,"hideDelay":100,"padding":5,"showDelay":0,"borderWidth":0,"showContent":true,"backgroundColor":"rgba(50,50,50,0.7)","trigger":"item","alwaysShowContent":false,"confine":false,"show":true},"grid":[{"height":"auto","show":false,"width":"auto","backgroundColor":"transparent"}],"title":[{"left":"left","borderColor":"transparent","bottom":"auto","padding":5,"zlevel":0,"borderWidth":1,"target":"blank","z":2,"itemGap":5,"shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","subtarget":"blank","show":true}],"ec_renderer":"canvas","legend":{"itemWidth":25,"data":["Series 1","Series 2"],"borderColor":"transparent","orient":"horizontal","bottom":"auto","height":"auto","zlevel":0,"padding":5,"borderWidth":1,"inactiveColor":"#ccc","z":2,"align":"auto","itemGap":10,"itemHeight":14,"backgroundColor":"transparent","shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","width":"auto","selectedMode":true,"show":true}}
        );
</script>

### Step Chart

{% highlight julia %}
using ECharts
x = ["Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"]
y = [11, 11, 15, 13, 12, 13, 10]
y2 = 3.7 .* y
astep = area(x, hcat(y, y2), step = "middle")
{% endhighlight %}

<div id="areaplot3" style="height:400px;width:800px;"></div>
<script type="text/javascript">

    // Initialize after dom ready
    var myChart = echarts.init(document.getElementById("areaplot3"), JSON.parse(roma()));

    // Load data into the ECharts instance
    myChart.setOption(
        {"xAxis":[{"splitNumber":5,"boundaryGap":false,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"data":["Monday","Tuesday","Wednesday","Thursday","Friday","Saturday","Sunday"],"scale":false,"gridIndex":0,"minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":30,"silent":true,"type":"category"}],"ec_charttype":"xy plot","series":[{"name":"Series 1","yAxisIndex":0,"step":"middle","areaStyle":{},"xAxisIndex":0,"stack":1,"smooth":false,"data":[11.0,11.0,15.0,13.0,12.0,13.0,10.0],"markLine":{"data":[],"lineStyle":{}},"type":"line"},{"name":"Series 2","yAxisIndex":0,"step":"middle","areaStyle":{},"xAxisIndex":0,"stack":1,"smooth":false,"data":[40.7,40.7,55.5,48.1,44.400000000000006,48.1,37.0],"markLine":{"data":[],"lineStyle":{}},"type":"line"}],"theme":{"geo":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"parallel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"markPoint":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}},"emphasis":{"textStyle":{"color":"#eeeeee"}}}},"visualMap":{"color":["#e01f54","#e7dbc3"]},"funnel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"bar":{"itemStyle":{"normal":{"barBorderColor":"#ccc","barBorderWidth":0},"emphasis":{"barBorderColor":"#ccc","barBorderWidth":0}}},"map":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"scatter":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"pie":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"graph":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}}},"symbolSize":4,"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"}},"smooth":false,"symbol":"emptyCircle","color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"lineStyle":{"normal":{"color":"#aaaaaa","width":1}}},"backgroundColor":"rgba(0,0,0,0)","line":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"candlestick":{"itemStyle":{"normal":{"borderColor0":"#b8d2c7","color":"#e01f54","borderColor":"#f5e8c8","borderWidth":1,"color0":"#001852"}}},"sankey":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"valueAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"toolbox":{"iconStyle":{"normal":{"borderColor":"#999999"},"emphasis":{"borderColor":"#666666"}}},"categoryAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"tooltip":{"axisPointer":{"crossStyle":{"color":"#cccccc","width":1},"lineStyle":{"color":"#cccccc","width":1}}},"timeline":{"label":{"normal":{"textStyle":{"color":"#293c55"}},"emphasis":{"textStyle":{"color":"#293c55"}}},"controlStyle":{"normal":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5},"emphasis":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5}},"checkpointStyle":{"color":"#e43c59","borderColor":"rgba(194,53,49,0.5)"},"itemStyle":{"normal":{"color":"#293c55","borderWidth":1},"emphasis":{"color":"#a9334c"}},"lineStyle":{"color":"#293c55","width":1}},"radar":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"logAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"textStyle":{},"gauge":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"boxplot":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"title":{"textStyle":{"color":"#333333"},"subtextStyle":{"color":"#aaaaaa"}},"dataZoom":{"dataBackgroundColor":"rgba(47,69,84,0.3)","textStyle":{"color":"#333333"},"handleSize":"100%","handleColor":"#a7b7cc","fillerColor":"rgba(167,183,204,0.4)","backgroundColor":"rgba(47,69,84,0)"},"timeAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"legend":{"textStyle":{"color":"#333333"}}},"yAxis":[{"splitNumber":5,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"scale":false,"gridIndex":0,"minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":50,"silent":true,"type":"value"}],"toolbox":{"feature":{},"orient":"vertical","itemSize":15,"height":"auto","zlevel":0,"z":2,"itemGap":20,"right":"auto","top":"center","width":"auto","show":false,"showTitle":true},"ec_width":800,"ec_height":400,"tooltip":{"triggerOn":"mousemove","enterable":true,"borderColor":"#333","transitionDuration":0.4,"hideDelay":100,"padding":5,"showDelay":0,"borderWidth":0,"showContent":true,"backgroundColor":"rgba(50,50,50,0.7)","trigger":"item","alwaysShowContent":false,"confine":false,"show":true},"grid":[{"height":"auto","show":false,"width":"auto","backgroundColor":"transparent"}],"title":[{"left":"left","borderColor":"transparent","bottom":"auto","padding":5,"zlevel":0,"borderWidth":1,"target":"blank","z":2,"itemGap":5,"shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","subtarget":"blank","show":true}],"ec_renderer":"canvas","legend":{"itemWidth":25,"data":["Series 1","Series 2"],"borderColor":"transparent","orient":"horizontal","bottom":"auto","height":"auto","zlevel":0,"padding":5,"borderWidth":1,"inactiveColor":"#ccc","z":2,"align":"auto","itemGap":10,"itemHeight":14,"backgroundColor":"transparent","shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","width":"auto","selectedMode":true,"show":true}}
        );
</script>

### DataFrame with `group` argument
{% highlight julia %}
using ECharts, DataFrames
x = [0,1,2,3,4,5,6,7,8,9,0,1,2,3,4,5,6,7,8,9]
y = [28, 43, 81, 19, 52, 24, 87, 17, 68, 49, 55, 91, 53, 87, 48, 49, 66, 27, 16, 15]
g = [0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1]
df_merged = DataFrame(x = x, y = y, g = g)
adfg = area(df_merged, :x, :y, :g)
{% endhighlight %}

<div id="adfg" style="height:400px;width:800px;"></div>
<script type="text/javascript">

    // Initialize after dom ready
    var myChart = echarts.init(document.getElementById("adfg"), JSON.parse(roma()));

    // Load data into the ECharts instance
    myChart.setOption(
{"xAxis":[{"splitNumber":5,"boundaryGap":false,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"data":[0,1,2,3,4,5,6,7,8,9],"scale":false,"gridIndex":0,"name":"x","minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":30,"silent":true,"type":"category"}],"ec_charttype":"xy plot","series":[{"name":"0","yAxisIndex":0,"areaStyle":{},"xAxisIndex":0,"stack":1,"smooth":false,"data":[28,43,81,19,52,24,87,17,68,49],"markLine":{"data":[],"lineStyle":{}},"type":"line"},{"name":"1","yAxisIndex":0,"areaStyle":{},"xAxisIndex":0,"stack":1,"smooth":false,"data":[55,91,53,87,48,49,66,27,16,15],"markLine":{"data":[],"lineStyle":{}},"type":"line"}],"theme":{"geo":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"parallel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"markPoint":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}},"emphasis":{"textStyle":{"color":"#eeeeee"}}}},"visualMap":{"color":["#e01f54","#e7dbc3"]},"funnel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"bar":{"itemStyle":{"normal":{"barBorderColor":"#ccc","barBorderWidth":0},"emphasis":{"barBorderColor":"#ccc","barBorderWidth":0}}},"map":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"scatter":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"pie":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"graph":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}}},"symbolSize":4,"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"}},"smooth":false,"symbol":"emptyCircle","color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"lineStyle":{"normal":{"color":"#aaaaaa","width":1}}},"backgroundColor":"rgba(0,0,0,0)","line":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"candlestick":{"itemStyle":{"normal":{"borderColor0":"#b8d2c7","color":"#e01f54","borderColor":"#f5e8c8","borderWidth":1,"color0":"#001852"}}},"sankey":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"valueAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"toolbox":{"iconStyle":{"normal":{"borderColor":"#999999"},"emphasis":{"borderColor":"#666666"}}},"categoryAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"tooltip":{"axisPointer":{"crossStyle":{"color":"#cccccc","width":1},"lineStyle":{"color":"#cccccc","width":1}}},"timeline":{"label":{"normal":{"textStyle":{"color":"#293c55"}},"emphasis":{"textStyle":{"color":"#293c55"}}},"controlStyle":{"normal":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5},"emphasis":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5}},"checkpointStyle":{"color":"#e43c59","borderColor":"rgba(194,53,49,0.5)"},"itemStyle":{"normal":{"color":"#293c55","borderWidth":1},"emphasis":{"color":"#a9334c"}},"lineStyle":{"color":"#293c55","width":1}},"radar":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"logAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"textStyle":{},"gauge":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"boxplot":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"title":{"textStyle":{"color":"#333333"},"subtextStyle":{"color":"#aaaaaa"}},"dataZoom":{"dataBackgroundColor":"rgba(47,69,84,0.3)","textStyle":{"color":"#333333"},"handleSize":"100%","handleColor":"#a7b7cc","fillerColor":"rgba(167,183,204,0.4)","backgroundColor":"rgba(47,69,84,0)"},"timeAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"legend":{"textStyle":{"color":"#333333"}}},"yAxis":[{"splitNumber":5,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"scale":false,"gridIndex":0,"name":"y","minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":50,"silent":true,"type":"value"}],"toolbox":{"feature":{},"orient":"vertical","itemSize":15,"height":"auto","zlevel":0,"z":2,"itemGap":20,"right":"auto","top":"center","width":"auto","show":false,"showTitle":true},"ec_width":800,"ec_height":400,"tooltip":{"triggerOn":"mousemove","enterable":true,"borderColor":"#333","transitionDuration":0.4,"hideDelay":100,"padding":5,"showDelay":0,"borderWidth":0,"showContent":true,"backgroundColor":"rgba(50,50,50,0.7)","trigger":"item","alwaysShowContent":false,"confine":false,"show":true},"grid":[{"height":"auto","show":false,"width":"auto","backgroundColor":"transparent"}],"title":[{"left":"left","borderColor":"transparent","bottom":"auto","padding":5,"zlevel":0,"borderWidth":1,"target":"blank","z":2,"itemGap":5,"shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","subtarget":"blank","show":true}],"ec_renderer":"canvas","legend":{"itemWidth":25,"data":["0","1"],"borderColor":"transparent","orient":"horizontal","bottom":"auto","height":"auto","zlevel":0,"padding":5,"borderWidth":1,"inactiveColor":"#ccc","z":2,"align":"auto","itemGap":10,"itemHeight":14,"backgroundColor":"transparent","shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","width":"auto","selectedMode":true,"show":true}}
        );
</script>

### UnivariateKDE

{% highlight julia %}
using ECharts
using KernelDensity, Distributions

#Set seed for repeatability
srand(1234)

#Generate Beta dist, calculate kernel density estimate
x = rand(Beta(3.0, 2.0), 10)
k = kde(x)

a = area(k)
{% endhighlight %}

<div id="dens" style="height:400px;width:800px;"></div>
<script type="text/javascript">

    // Initialize after dom ready
    var myChart = echarts.init(document.getElementById("dens"), JSON.parse(roma()));

    // Load data into the ECharts instance
    myChart.setOption(
        {"xAxis":[{"splitNumber":5,"boundaryGap":false,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"data":[-0.06054967139047107,-0.05987475046044425,-0.05919982953041743,-0.058524908600390606,-0.057849987670363784,-0.057175066740336955,-0.05650014581031013,-0.05582522488028331,-0.05515030395025649,-0.05447538302022967,-0.053800462090202845,-0.053125541160176024,-0.0524506202301492,-0.05177569930012238,-0.05110077837009555,-0.05042585744006873,-0.04975093651004191,-0.049076015580015085,-0.04840109464998826,-0.04772617371996144,-0.04705125278993462,-0.0463763318599078,-0.045701410929880976,-0.04502648999985415,-0.044351569069827325,-0.0436766481398005,-0.04300172720977368,-0.04232680627974686,-0.04165188534972004,-0.040976964419693215,-0.04030204348966639,-0.03962712255963957,-0.03895220162961274,-0.03827728069958592,-0.0376023597695591,-0.03692743883953228,-0.036252517909505455,-0.03557759697947863,-0.03490267604945181,-0.03422775511942499,-0.03355283418939817,-0.032877913259371346,-0.03220299232934452,-0.031528071399317695,-0.030853150469290873,-0.03017822953926405,-0.02950330860923723,-0.028828387679210407,-0.028153466749183585,-0.02747854581915676,-0.026803624889129938,-0.026128703959103116,-0.025453783029076294,-0.02477886209904947,-0.024103941169022647,-0.023429020238995825,-0.022754099308969003,-0.02207917837894218,-0.021404257448915356,-0.020729336518888534,-0.020054415588861712,-0.01937949465883489,-0.018704573728808065,-0.018029652798781243,-0.01735473186875442,-0.0166798109387276,-0.016004890008700777,-0.015329969078673953,-0.01465504814864713,-0.013980127218620308,-0.013305206288593484,-0.012630285358566662,-0.011955364428539839,-0.011280443498513017,-0.010605522568486195,-0.009930601638459371,-0.00925568070843255,-0.008580759778405726,-0.007905838848378904,-0.007230917918352081,-0.006555996988325258,-0.005881076058298435,-0.005206155128271613,-0.00453123419824479,-0.0038563132682179675,-0.0031813923381911447,-0.0025064714081643224,-0.0018315504781374996,-0.0011566295481106768,-0.00048170861808385413,0.00019321231194296853,0.0008681332419697912,0.0015430541719966139,0.0022179751020234366,0.002892896032050259,0.0035678169620770818,0.0042427378921039045,0.004917658822130727,0.00559257975215755,0.006267500682184373,0.006942421612211196,0.0076173425422380175,0.008292263472264841,0.008967184402291663,0.009642105332318487,0.010317026262345309,0.01099194719237213,0.011666868122398954,0.012341789052425776,0.0130167099824526,0.013691630912479422,0.014366551842506245,0.015041472772533067,0.01571639370255989,0.016391314632586713,0.017066235562613535,0.017741156492640357,0.018416077422667182,0.019090998352694004,0.019765919282720826,0.020440840212747648,0.02111576114277447,0.021790682072801295,0.022465603002828117,0.02314052393285494,0.02381544486288176,0.024490365792908586,0.025165286722935408,0.02584020765296223,0.026515128582989052,0.027190049513015874,0.0278649704430427,0.02853989137306952,0.029214812303096343,0.029889733233123165,0.03056465416314999,0.031239575093176812,0.031914496023203634,0.032589416953230456,0.03326433788325728,0.0339392588132841,0.03461417974331092,0.03528910067333775,0.03596402160336457,0.036638942533391394,0.037313863463418216,0.03798878439344504,0.03866370532347186,0.03933862625349868,0.040013547183525504,0.040688468113552326,0.041363389043579155,0.042038309973605976,0.0427132309036328,0.04338815183365962,0.04406307276368644,0.044737993693713264,0.045412914623740086,0.04608783555376691,0.04676275648379373,0.04743767741382056,0.04811259834384738,0.0487875192738742,0.049462440203901024,0.050137361133927846,0.05081228206395467,0.05148720299398149,0.05216212392400831,0.052837044854035134,0.053511965784061956,0.054186886714088785,0.05486180764411561,0.05553672857414243,0.05621164950416925,0.05688657043419607,0.057561491364222894,0.058236412294249716,0.05891133322427654,0.05958625415430336,0.06026117508433019,0.06093609601435701,0.06161101694438383,0.062285937874410655,0.06296085880443748,0.0636357797344643,0.06431070066449113,0.06498562159451794,0.06566054252454477,0.06633546345457159,0.06701038438459841,0.06768530531462523,0.06836022624465206,0.06903514717467887,0.0697100681047057,0.07038498903473253,0.07105990996475935,0.07173483089478618,0.07240975182481299,0.07308467275483982,0.07375959368486663,0.07443451461489346,0.07510943554492028,0.0757843564749471,0.07645927740497394,0.07713419833500075,0.07780911926502758,0.0784840401950544,0.07915896112508122,0.07983388205510804,0.08050880298513487,0.08118372391516168,0.08185864484518851,0.08253356577521534,0.08320848670524215,0.08388340763526898,0.0845583285652958,0.08523324949532263,0.08590817042534944,0.08658309135537627,0.08725801228540309,0.08793293321542991,0.08860785414545674,0.08928277507548356,0.08995769600551039,0.0906326169355372,0.09130753786556403,0.09198245879559085,0.09265737972561768,0.09333230065564449,0.09400722158567132,0.09468214251569815,0.09535706344572496,0.09603198437575179,0.0967069053057786,0.09738182623580544,0.09805674716583225,0.09873166809585908,0.0994065890258859,0.10008150995591272,0.10075643088593955,0.10143135181596637,0.1021062727459932,0.10278119367602001,0.10345611460604684,0.10413103553607365,0.10480595646610048,0.1054808773961273,0.10615579832615413,0.10683071925618096,0.10750564018620777,0.1081805611162346,0.10885548204626141,0.10953040297628824,0.11020532390631506,0.11088024483634189,0.1115551657663687,0.11223008669639553,0.11290500762642236,0.11357992855644918,0.114254849486476,0.11492977041650282,0.11560469134652965,0.11627961227655646,0.11695453320658329,0.1176294541366101,0.11830437506663694,0.11897929599666376,0.11965421692669058,0.12032913785671741,0.12100405878674422,0.12167897971677105,0.12235390064679787,0.1230288215768247,0.12370374250685151,0.12437866343687834,0.12505358436690517,0.125728505296932,0.1264034262269588,0.12707834715698563,0.12775326808701246,0.12842818901703928,0.12910310994706609,0.12977803087709291,0.13045295180711974,0.13112787273714657,0.1318027936671734,0.1324777145972002,0.13315263552722703,0.13382755645725386,0.1345024773872807,0.1351773983173075,0.13585231924733432,0.13652724017736115,0.13720216110738798,0.1378770820374148,0.1385520029674416,0.13922692389746844,0.13990184482749526,0.1405767657575221,0.1412516866875489,0.14192660761757572,0.14260152854760255,0.14327644947762938,0.1439513704076562,0.144626291337683,0.14530121226770984,0.14597613319773667,0.1466510541277635,0.1473259750577903,0.14800089598781713,0.14867581691784396,0.14935073784787078,0.1500256587778976,0.15070057970792441,0.15137550063795124,0.15205042156797807,0.1527253424980049,0.1534002634280317,0.15407518435805853,0.15475010528808536,0.1554250262181122,0.15609994714813902,0.15677486807816582,0.15744978900819265,0.15812470993821948,0.1587996308682463,0.1594745517982731,0.16014947272829994,0.16082439365832676,0.1614993145883536,0.16217423551838042,0.16284915644840722,0.16352407737843405,0.16419899830846088,0.1648739192384877,0.1655488401685145,0.16622376109854134,0.16689868202856817,0.167573602958595,0.16824852388862183,0.16892344481864863,0.16959836574867546,0.17027328667870228,0.1709482076087291,0.17162312853875591,0.17229804946878274,0.17297297039880957,0.1736478913288364,0.17432281225886323,0.17499773318889003,0.17567265411891686,0.1763475750489437,0.17702249597897052,0.17769741690899732,0.17837233783902415,0.17904725876905098,0.1797221796990778,0.18039710062910463,0.18107202155913144,0.18174694248915826,0.1824218634191851,0.18309678434921192,0.18377170527923872,0.18444662620926555,0.18512154713929238,0.1857964680693192,0.18647138899934604,0.18714630992937284,0.18782123085939967,0.1884961517894265,0.18917107271945333,0.18984599364948013,0.19052091457950696,0.19119583550953378,0.1918707564395606,0.19254567736958744,0.19322059829961424,0.19389551922964107,0.1945704401596679,0.19524536108969473,0.19592028201972153,0.19659520294974836,0.1972701238797752,0.19794504480980202,0.19861996573982882,0.19929488666985565,0.19996980759988248,0.2006447285299093,0.20131964945993613,0.20199457038996294,0.20266949131998976,0.2033444122500166,0.20401933318004342,0.20469425411007022,0.20536917504009705,0.20604409597012388,0.2067190169001507,0.20739393783017754,0.20806885876020434,0.20874377969023117,0.209418700620258,0.21009362155028483,0.21076854248031163,0.21144346341033846,0.21211838434036528,0.2127933052703921,0.21346822620041894,0.21414314713044574,0.21481806806047257,0.2154929889904994,0.21616790992052623,0.21684283085055303,0.21751775178057986,0.2181926727106067,0.21886759364063352,0.21954251457066035,0.22021743550068715,0.22089235643071398,0.2215672773607408,0.22224219829076763,0.22291711922079444,0.22359204015082126,0.2242669610808481,0.22494188201087492,0.22561680294090175,0.22629172387092855,0.22696664480095538,0.2276415657309822,0.22831648666100904,0.22899140759103584,0.22966632852106267,0.2303412494510895,0.23101617038111633,0.23169109131114315,0.23236601224116996,0.23304093317119678,0.2337158541012236,0.23439077503125044,0.23506569596127724,0.23574061689130407,0.2364155378213309,0.23709045875135773,0.23776537968138456,0.23844030061141136,0.2391152215414382,0.23979014247146502,0.24046506340149185,0.24113998433151865,0.24181490526154548,0.2424898261915723,0.24316474712159913,0.24383966805162596,0.24451458898165276,0.2451895099116796,0.24586443084170642,0.24653935177173325,0.24721427270176005,0.24788919363178688,0.2485641145618137,0.24923903549184054,0.24991395642186737,0.25058887735189417,0.251263798281921,0.2519387192119478,0.2526136401419746,0.2532885610720015,0.2539634820020283,0.25463840293205514,0.25531332386208194,0.25598824479210874,0.2566631657221356,0.2573380866521624,0.2580130075821892,0.25868792851221606,0.25936284944224286,0.2600377703722697,0.2607126913022965,0.2613876122323233,0.2620625331623502,0.262737454092377,0.26341237502240383,0.26408729595243063,0.26476221688245744,0.2654371378124843,0.2661120587425111,0.26678697967253795,0.26746190060256475,0.26813682153259155,0.2688117424626184,0.2694866633926452,0.270161584322672,0.27083650525269887,0.27151142618272567,0.2721863471127525,0.2728612680427793,0.2735361889728061,0.274211109902833,0.2748860308328598,0.27556095176288664,0.27623587269291344,0.27691079362294024,0.2775857145529671,0.2782606354829939,0.27893555641302076,0.27961047734304756,0.28028539827307436,0.2809603192031012,0.281635240133128,0.2823101610631548,0.2829850819931817,0.2836600029232085,0.28433492385323533,0.28500984478326213,0.28568476571328894,0.2863596866433158,0.2870346075733426,0.28770952850336945,0.28838444943339625,0.28905937036342305,0.2897342912934499,0.2904092122234767,0.2910841331535035,0.29175905408353037,0.29243397501355717,0.293108895943584,0.2937838168736108,0.2944587378036376,0.2951336587336645,0.2958085796636913,0.29648350059371814,0.29715842152374494,0.29783334245377174,0.2985082633837986,0.2991831843138254,0.29985810524385226,0.30053302617387906,0.30120794710390586,0.3018828680339327,0.3025577889639595,0.3032327098939863,0.3039076308240132,0.30458255175404,0.30525747268406683,0.30593239361409363,0.30660731454412044,0.3072822354741473,0.3079571564041741,0.30863207733420095,0.30930699826422775,0.30998191919425455,0.3106568401242814,0.3113317610543082,0.31200668198433507,0.31268160291436187,0.31335652384438867,0.3140314447744155,0.3147063657044423,0.3153812866344691,0.316056207564496,0.3167311284945228,0.31740604942454964,0.31808097035457644,0.31875589128460324,0.3194308122146301,0.3201057331446569,0.32078065407468376,0.32145557500471056,0.32213049593473736,0.3228054168647642,0.323480337794791,0.3241552587248179,0.3248301796548447,0.3255051005848715,0.32618002151489833,0.32685494244492513,0.32752986337495194,0.3282047843049788,0.3288797052350056,0.32955462616503245,0.33022954709505925,0.33090446802508605,0.3315793889551129,0.3322543098851397,0.33292923081516657,0.33360415174519337,0.33427907267522017,0.334953993605247,0.3356289145352738,0.3363038354653007,0.3369787563953275,0.3376536773253543,0.33832859825538114,0.33900351918540794,0.33967844011543474,0.3403533610454616,0.3410282819754884,0.34170320290551526,0.34237812383554206,0.34305304476556886,0.3437279656955957,0.3444028866256225,0.3450778075556494,0.3457527284856762,0.346427649415703,0.34710257034572983,0.34777749127575663,0.3484524122057835,0.3491273331358103,0.3498022540658371,0.35047717499586395,0.35115209592589075,0.35182701685591755,0.3525019377859444,0.3531768587159712,0.35385177964599807,0.35452670057602487,0.35520162150605167,0.3558765424360785,0.3565514633661053,0.3572263842961322,0.357901305226159,0.3585762261561858,0.35925114708621264,0.35992606801623944,0.3606009889462663,0.3612759098762931,0.3619508308063199,0.36262575173634676,0.36330067266637356,0.36397559359640036,0.3646505145264272,0.365325435456454,0.3660003563864809,0.3666752773165077,0.3673501982465345,0.36802511917656133,0.36870004010658813,0.369374961036615,0.3700498819666418,0.3707248028966686,0.37139972382669545,0.37207464475672225,0.3727495656867491,0.3734244866167759,0.3740994075468027,0.37477432847682957,0.37544924940685637,0.37612417033688317,0.37679909126691,0.3774740121969368,0.3781489331269637,0.3788238540569905,0.3794987749870173,0.38017369591704414,0.38084861684707094,0.3815235377770978,0.3821984587071246,0.3828733796371514,0.38354830056717826,0.38422322149720506,0.3848981424272319,0.3855730633572587,0.3862479842872855,0.3869229052173124,0.3875978261473392,0.388272747077366,0.38894766800739283,0.38962258893741963,0.3902975098674465,0.3909724307974733,0.3916473517275001,0.39232227265752695,0.39299719358755375,0.3936721145175806,0.3943470354476074,0.3950219563776342,0.39569687730766107,0.39637179823768787,0.3970467191677147,0.3977216400977415,0.3983965610277683,0.3990714819577952,0.399746402887822,0.4004213238178488,0.40109624474787564,0.40177116567790244,0.4024460866079293,0.4031210075379561,0.4037959284679829,0.40447084939800976,0.40514577032803656,0.4058206912580634,0.4064956121880902,0.407170533118117,0.4078454540481439,0.4085203749781707,0.40919529590819753,0.40987021683822433,0.41054513776825113,0.411220058698278,0.4118949796283048,0.4125699005583316,0.41324482148835845,0.41391974241838525,0.4145946633484121,0.4152695842784389,0.4159445052084657,0.41661942613849257,0.41729434706851937,0.4179692679985462,0.418644188928573,0.4193191098585998,0.4199940307886267,0.4206689517186535,0.42134387264868034,0.42201879357870714,0.42269371450873394,0.4233686354387608,0.4240435563687876,0.4247184772988144,0.42539339822884126,0.42606831915886806,0.4267432400888949,0.4274181610189217,0.4280930819489485,0.4287680028789754,0.4294429238090022,0.43011784473902903,0.43079276566905583,0.43146768659908263,0.4321426075291095,0.4328175284591363,0.43349244938916315,0.43416737031918995,0.43484229124921675,0.4355172121792436,0.4361921331092704,0.4368670540392972,0.43754197496932407,0.43821689589935087,0.4388918168293777,0.4395667377594045,0.4402416586894313,0.4409165796194582,0.441591500549485,0.44226642147951184,0.44294134240953864,0.44361626333956544,0.4442911842695923,0.4449661051996191,0.44564102612964596,0.44631594705967276,0.44699086798969956,0.4476657889197264,0.4483407098497532,0.44901563077978,0.4496905517098069,0.4503654726398337,0.45104039356986053,0.45171531449988733,0.45239023542991413,0.453065156359941,0.4537400772899678,0.45441499821999465,0.45508991915002145,0.45576484008004825,0.4564397610100751,0.4571146819401019,0.4577896028701287,0.45846452380015557,0.45913944473018237,0.4598143656602092,0.460489286590236,0.4611642075202628,0.4618391284502897,0.4625140493803165,0.46318897031034334,0.46386389124037014,0.46453881217039694,0.4652137331004238,0.4658886540304506,0.46656357496047746,0.46723849589050426,0.46791341682053106,0.4685883377505579,0.4692632586805847,0.4699381796106115,0.4706131005406384,0.4712880214706652,0.47196294240069203,0.47263786333071883,0.47331278426074563,0.4739877051907725,0.4746626261207993,0.47533754705082615,0.47601246798085295,0.47668738891087975,0.4773623098409066,0.4780372307709334,0.47871215170096026,0.47938707263098707,0.48006199356101387,0.4807369144910407,0.4814118354210675,0.4820867563510943,0.4827616772811212,0.483436598211148,0.48411151914117484,0.48478644007120164,0.48546136100122844,0.4861362819312553,0.4868112028612821,0.48748612379130896,0.48816104472133576,0.48883596565136256,0.4895108865813894,0.4901858075114162,0.4908607284414431,0.4915356493714699,0.4922105703014967,0.49288549123152353,0.49356041216155033,0.49423533309157713,0.494910254021604,0.4955851749516308,0.49626009588165765,0.49693501681168445,0.49760993774171125,0.4982848586717381,0.4989597796017649,0.49963470053179176,0.5003096214618186,0.5009845423918454,0.5016594633218722,0.502334384251899,0.5030093051819259,0.5036842261119526,0.5043591470419795,0.5050340679720063,0.5057089889020332,0.5063839098320599,0.5070588307620868,0.5077337516921137,0.5084086726221404,0.5090835935521673,0.5097585144821941,0.5104334354122209,0.5111083563422477,0.5117832772722746,0.5124581982023013,0.5131331191323282,0.513808040062355,0.5144829609923819,0.5151578819224086,0.5158328028524355,0.5165077237824623,0.5171826447124891,0.517857565642516,0.5185324865725428,0.5192074075025696,0.5198823284325964,0.5205572493626233,0.5212321702926501,0.5219070912226769,0.5225820121527037,0.5232569330827306,0.5239318540127573,0.5246067749427842,0.525281695872811,0.5259566168028378,0.5266315377328646,0.5273064586628915,0.5279813795929182,0.5286563005229451,0.529331221452972,0.5300061423829988,0.5306810633130256,0.5313559842430524,0.5320309051730793,0.532705826103106,0.5333807470331329,0.5340556679631597,0.5347305888931865,0.5354055098232133,0.5360804307532402,0.5367553516832669,0.5374302726132938,0.5381051935433206,0.5387801144733475,0.5394550354033743,0.5401299563334011,0.540804877263428,0.5414797981934547,0.5421547191234816,0.5428296400535084,0.5435045609835352,0.544179481913562,0.5448544028435889,0.5455293237736157,0.5462042447036425,0.5468791656336693,0.5475540865636962,0.5482290074937229,0.5489039284237498,0.5495788493537767,0.5502537702838034,0.5509286912138303,0.5516036121438571,0.5522785330738839,0.5529534540039107,0.5536283749339376,0.5543032958639644,0.5549782167939912,0.555653137724018,0.5563280586540449,0.5570029795840716,0.5576779005140985,0.5583528214441253,0.5590277423741521,0.559702663304179,0.5603775842342058,0.5610525051642326,0.5617274260942594,0.5624023470242863,0.5630772679543131,0.5637521888843399,0.5644271098143667,0.5651020307443936,0.5657769516744203,0.5664518726044472,0.567126793534474,0.5678017144645008,0.5684766353945276,0.5691515563245545,0.5698264772545814,0.5705013981846081,0.571176319114635,0.5718512400446618,0.5725261609746886,0.5732010819047154,0.5738760028347423,0.574550923764769,0.5752258446947959,0.5759007656248227,0.5765756865548495,0.5772506074848763,0.5779255284149032,0.57860044934493,0.5792753702749568,0.5799502912049836,0.5806252121350105,0.5813001330650373,0.5819750539950641,0.582649974925091,0.5833248958551177,0.5839998167851446,0.5846747377151714,0.5853496586451982,0.586024579575225,0.5866995005052519,0.5873744214352787,0.5880493423653055,0.5887242632953323,0.5893991842253592,0.5900741051553859,0.5907490260854128,0.5914239470154397,0.5920988679454664,0.5927737888754933,0.5934487098055201,0.594123630735547,0.5947985516655737,0.5954734725956006,0.5961483935256274,0.5968233144556542,0.597498235385681,0.5981731563157079,0.5988480772457346,0.5995229981757615,0.6001979191057883,0.6008728400358151,0.601547760965842,0.6022226818958688,0.6028976028258957,0.6035725237559224,0.6042474446859493,0.6049223656159761,0.6055972865460029,0.6062722074760297,0.6069471284060566,0.6076220493360833,0.6082969702661102,0.608971891196137,0.6096468121261638,0.6103217330561906,0.6109966539862175,0.6116715749162444,0.6123464958462711,0.613021416776298,0.6136963377063248,0.6143712586363516,0.6150461795663784,0.6157211004964053,0.616396021426432,0.6170709423564589,0.6177458632864857,0.6184207842165126,0.6190957051465393,0.6197706260765662,0.620445547006593,0.6211204679366198,0.6217953888666466,0.6224703097966735,0.6231452307267002,0.6238201516567271,0.624495072586754,0.6251699935167807,0.6258449144468076,0.6265198353768344,0.6271947563068613,0.627869677236888,0.6285445981669149,0.6292195190969417,0.6298944400269685,0.6305693609569953,0.6312442818870222,0.6319192028170489,0.6325941237470758,0.6332690446771027,0.6339439656071294,0.6346188865371563,0.6352938074671831,0.63596872839721,0.6366436493272367,0.6373185702572636,0.6379934911872904,0.6386684121173172,0.639343333047344,0.6400182539773709,0.6406931749073976,0.6413680958374245,0.6420430167674513,0.6427179376974781,0.643392858627505,0.6440677795575318,0.6447427004875587,0.6454176214175854,0.6460925423476123,0.6467674632776391,0.6474423842076659,0.6481173051376927,0.6487922260677196,0.6494671469977463,0.6501420679277732,0.6508169888578,0.6514919097878269,0.6521668307178536,0.6528417516478805,0.6535166725779074,0.6541915935079341,0.654866514437961,0.6555414353679878,0.6562163562980146,0.6568912772280414,0.6575661981580683,0.658241119088095,0.6589160400181219,0.6595909609481487,0.6602658818781756,0.6609408028082023,0.6616157237382292,0.662290644668256,0.6629655655982828,0.6636404865283096,0.6643154074583365,0.6649903283883632,0.6656652493183901,0.666340170248417,0.6670150911784437,0.6676900121084706,0.6683649330384974,0.6690398539685243,0.669714774898551,0.6703896958285779,0.6710646167586047,0.6717395376886315,0.6724144586186583,0.6730893795486852,0.6737643004787119,0.6744392214087388,0.6751141423387657,0.6757890632687925,0.6764639841988193,0.6771389051288461,0.677813826058873,0.6784887469888997,0.6791636679189266,0.6798385888489534,0.6805135097789802,0.681188430709007,0.6818633516390339,0.6825382725690606,0.6832131934990875,0.6838881144291143,0.6845630353591412,0.685237956289168,0.6859128772191948,0.6865877981492217,0.6872627190792484,0.6879376400092753,0.6886125609393021,0.6892874818693289,0.6899624027993557,0.6906373237293826,0.6913122446594093,0.6919871655894362,0.692662086519463,0.6933370074494899,0.6940119283795166,0.6946868493095435,0.6953617702395704,0.6960366911695971,0.696711612099624,0.6973865330296508,0.6980614539596776,0.6987363748897044,0.6994112958197313,0.7000862167497581,0.7007611376797849,0.7014360586098117,0.7021109795398386,0.7027859004698653,0.7034608213998922,0.704135742329919,0.7048106632599458,0.7054855841899726,0.7061605051199995,0.7068354260500262,0.7075103469800531,0.70818526791008,0.7088601888401068,0.7095351097701336,0.7102100307001604,0.7108849516301873,0.711559872560214,0.7122347934902409,0.7129097144202677,0.7135846353502945,0.7142595562803213,0.7149344772103482,0.7156093981403749,0.7162843190704018,0.7169592400004287,0.7176341609304555,0.7183090818604823,0.7189840027905091,0.719658923720536,0.7203338446505627,0.7210087655805896,0.7216836865106164,0.7223586074406432,0.72303352837067,0.7237084493006969,0.7243833702307237,0.7250582911607505,0.7257332120907773,0.7264081330208042,0.727083053950831,0.7277579748808578,0.7284328958108847,0.7291078167409114,0.7297827376709383,0.7304576586009651,0.7311325795309919,0.7318075004610187,0.7324824213910456,0.7331573423210724,0.7338322632510992,0.734507184181126,0.7351821051111529,0.7358570260411796,0.7365319469712065,0.7372068679012334,0.7378817888312601,0.738556709761287,0.7392316306913138,0.7399065516213406,0.7405814725513674,0.7412563934813943,0.7419313144114211,0.7426062353414479,0.7432811562714747,0.7439560772015016,0.7446309981315283,0.7453059190615552,0.745980839991582,0.7466557609216088,0.7473306818516356,0.7480056027816625,0.7486805237116894,0.7493554446417161,0.750030365571743,0.7507052865017698,0.7513802074317966,0.7520551283618234,0.7527300492918503,0.753404970221877,0.7540798911519039,0.7547548120819307,0.7554297330119575,0.7561046539419843,0.7567795748720112,0.757454495802038,0.7581294167320648,0.7588043376620917,0.7594792585921185,0.7601541795221453,0.7608291004521721,0.761504021382199,0.7621789423122257,0.7628538632422526,0.7635287841722794,0.7642037051023062,0.764878626032333,0.7655535469623599,0.7662284678923867,0.7669033888224135,0.7675783097524403,0.7682532306824672,0.768928151612494,0.7696030725425208,0.7702779934725477,0.7709529144025744,0.7716278353326013,0.7723027562626281,0.772977677192655,0.7736525981226817,0.7743275190527086,0.7750024399827354,0.7756773609127622,0.776352281842789,0.7770272027728159,0.7777021237028426,0.7783770446328695,0.7790519655628964,0.7797268864929231,0.78040180742295,0.7810767283529768,0.7817516492830037,0.7824265702130304,0.7831014911430573,0.7837764120730841,0.7844513330031109,0.7851262539331377,0.7858011748631646,0.7864760957931913,0.7871510167232182,0.787825937653245,0.7885008585832718,0.7891757795132986,0.7898507004433255,0.7905256213733524,0.7912005423033791,0.791875463233406,0.7925503841634328,0.7932253050934596,0.7939002260234864,0.7945751469535133,0.79525006788354,0.7959249888135669,0.7965999097435937,0.7972748306736206,0.7979497516036473,0.7986246725336742,0.799299593463701,0.7999745143937278,0.8006494353237547,0.8013243562537815,0.8019992771838083,0.8026741981138351,0.803349119043862,0.8040240399738887,0.8046989609039156,0.8053738818339424,0.8060488027639693,0.806723723693996,0.8073986446240229,0.8080735655540497,0.8087484864840765,0.8094234074141033,0.8100983283441302,0.810773249274157,0.8114481702041838,0.8121230911342107,0.8127980120642374,0.8134729329942643,0.8141478539242911,0.814822774854318,0.8154976957843447,0.8161726167143716,0.8168475376443984,0.8175224585744252,0.818197379504452,0.8188723004344789,0.8195472213645056,0.8202221422945325,0.8208970632245594,0.8215719841545861,0.822246905084613,0.8229218260146398,0.8235967469446667,0.8242716678746934,0.8249465888047203,0.8256215097347471,0.8262964306647739,0.8269713515948007,0.8276462725248276,0.8283211934548543,0.8289961143848812,0.829671035314908,0.8303459562449349,0.8310208771749616,0.8316957981049885,0.8323707190350154,0.8330456399650421,0.833720560895069,0.8343954818250958,0.8350704027551226,0.8357453236851494,0.8364202446151763,0.837095165545203,0.8377700864752299,0.8384450074052567,0.8391199283352836,0.8397948492653103,0.8404697701953372,0.841144691125364,0.8418196120553908,0.8424945329854177,0.8431694539154445,0.8438443748454713,0.8445192957754981,0.845194216705525,0.8458691376355517,0.8465440585655786,0.8472189794956054,0.8478939004256323,0.848568821355659,0.8492437422856859,0.8499186632157127,0.8505935841457395,0.8512685050757663,0.8519434260057932,0.85261834693582,0.8532932678658468,0.8539681887958737,0.8546431097259005,0.8553180306559273,0.8559929515859541,0.856667872515981,0.8573427934460077,0.8580177143760346,0.8586926353060614,0.8593675562360882,0.860042477166115,0.8607173980961419,0.8613923190261686,0.8620672399561955,0.8627421608862224,0.8634170818162492,0.864092002746276,0.8647669236763028,0.8654418446063297,0.8661167655363564,0.8667916864663833,0.8674666073964101,0.8681415283264369,0.8688164492564637,0.8694913701864906,0.8701662911165173,0.8708412120465442,0.871516132976571,0.8721910539065979,0.8728659748366246,0.8735408957666515,0.8742158166966784,0.8748907376267051,0.875565658556732,0.8762405794867588,0.8769155004167856,0.8775904213468124,0.8782653422768393,0.8789402632068661,0.8796151841368929,0.8802901050669197,0.8809650259969466,0.8816399469269733,0.8823148678570002,0.882989788787027,0.8836647097170538,0.8843396306470807,0.8850145515771075,0.8856894725071343,0.8863643934371611,0.887039314367188,0.8877142352972148,0.8883891562272416,0.8890640771572684,0.8897389980872953,0.890413919017322,0.8910888399473489,0.8917637608773757,0.8924386818074025,0.8931136027374293,0.8937885236674562,0.894463444597483,0.8951383655275098,0.8958132864575367,0.8964882073875635,0.8971631283175903,0.8978380492476171,0.898512970177644,0.8991878911076707,0.8998628120376976,0.9005377329677244,0.9012126538977512,0.901887574827778,0.9025624957578049,0.9032374166878318,0.9039123376178585,0.9045872585478854,0.9052621794779122,0.905937100407939,0.9066120213379658,0.9072869422679927,0.9079618631980194,0.9086367841280463,0.9093117050580731,0.9099866259880999,0.9106615469181267,0.9113364678481536,0.9120113887781804,0.9126863097082072,0.913361230638234,0.9140361515682609,0.9147110724982876,0.9153859934283145,0.9160609143583414,0.9167358352883681,0.917410756218395,0.9180856771484218,0.9187605980784486,0.9194355190084754,0.9201104399385023,0.9207853608685291,0.9214602817985559,0.9221352027285827,0.9228101236586096,0.9234850445886363,0.9241599655186632,0.92483488644869,0.9255098073787168,0.9261847283087437,0.9268596492387705,0.9275345701687974,0.9282094910988241,0.928884412028851,0.9295593329588778,0.9302342538889046,0.9309091748189314,0.9315840957489583,0.932259016678985,0.9329339376090119,0.9336088585390387,0.9342837794690655,0.9349587003990923,0.9356336213291192,0.9363085422591461,0.9369834631891728,0.9376583841191997,0.9383333050492265,0.9390082259792533,0.9396831469092801,0.940358067839307,0.9410329887693337,0.9417079096993606,0.9423828306293874,0.9430577515594142,0.943732672489441,0.9444075934194679,0.9450825143494948,0.9457574352795215,0.9464323562095484,0.9471072771395752,0.947782198069602,0.9484571189996288,0.9491320399296557,0.9498069608596824,0.9504818817897093,0.9511568027197361,0.951831723649763,0.9525066445797897,0.9531815655098166,0.9538564864398434,0.9545314073698702,0.955206328299897,0.9558812492299239,0.9565561701599506,0.9572310910899775,0.9579060120200044,0.9585809329500311,0.959255853880058,0.9599307748100848,0.9606056957401117,0.9612806166701384,0.9619555376001653,0.9626304585301921,0.9633053794602189,0.9639803003902457,0.9646552213202726,0.9653301422502993,0.9660050631803262,0.966679984110353,0.9673549050403798,0.9680298259704067,0.9687047469004335,0.9693796678304604,0.9700545887604871,0.970729509690514,0.9714044306205408,0.9720793515505676,0.9727542724805944,0.9734291934106213,0.974104114340648,0.9747790352706749,0.9754539562007017,0.9761288771307286,0.9768037980607553,0.9774787189907822,0.9781536399208091,0.9788285608508358,0.9795034817808627,0.9801784027108895,0.9808533236409163,0.9815282445709431,0.98220316550097,0.9828780864309967,0.9835530073610236,0.9842279282910504,0.9849028492210773,0.985577770151104,0.9862526910811309,0.9869276120111578,0.9876025329411845,0.9882774538712114,0.9889523748012382,0.989627295731265,0.9903022166612918,0.9909771375913187,0.9916520585213454,0.9923269794513723,0.9930019003813991,0.993676821311426,0.9943517422414527,0.9950266631714796,0.9957015841015064,0.9963765050315332,0.99705142596156,0.9977263468915869,0.9984012678216136,0.9990761887516405,0.9997511096816674,1.000426030611694,1.001100951541721,1.0017758724717478,1.0024507934017746,1.0031257143318015,1.0038006352618283,1.004475556191855,1.005150477121882,1.0058253980519087,1.0065003189819355,1.0071752399119624,1.0078501608419892,1.008525081772016,1.009200002702043,1.0098749236320697,1.0105498445620964,1.0112247654921234,1.0118996864221501,1.0125746073521769,1.0132495282822038,1.0139244492122306,1.0145993701422575,1.0152742910722843,1.015949212002311,1.016624132932338,1.0172990538623647,1.0179739747923915,1.0186488957224185,1.0193238166524452,1.019998737582472,1.020673658512499,1.0213485794425257,1.0220235003725524,1.0226984213025794,1.0233733422326061,1.0240482631626329,1.0247231840926598,1.0253981050226866,1.0260730259527133,1.0267479468827403,1.027422867812767,1.0280977887427938,1.0287727096728208,1.0294476306028475,1.0301225515328745,1.0307974724629012,1.031472393392928,1.032147314322955,1.0328222352529817,1.0334971561830084,1.0341720771130354,1.0348469980430621,1.0355219189730889,1.0361968399031158,1.0368717608331426,1.0375466817631693,1.0382216026931963,1.038896523623223,1.0395714445532498,1.0402463654832768,1.0409212864133035,1.0415962073433302,1.0422711282733572,1.042946049203384,1.0436209701334107,1.0442958910634377,1.0449708119934644,1.0456457329234914,1.0463206538535181,1.0469955747835449,1.0476704957135718,1.0483454166435986,1.0490203375736253,1.0496952585036523,1.050370179433679,1.0510451003637058,1.0517200212937328,1.0523949422237595,1.0530698631537863,1.0537447840838132,1.05441970501384,1.0550946259438667,1.0557695468738937,1.0564444678039204,1.0571193887339472,1.0577943096639741,1.0584692305940009,1.0591441515240276,1.0598190724540546,1.0604939933840813,1.061168914314108,1.061843835244135,1.0625187561741618,1.0631936771041888,1.0638685980342155,1.0645435189642423,1.0652184398942692,1.065893360824296,1.0665682817543227,1.0672432026843497,1.0679181236143764,1.0685930445444032,1.0692679654744301,1.069942886404457,1.0706178073344836,1.0712927282645106,1.0719676491945374,1.072642570124564,1.073317491054591,1.0739924119846178,1.0746673329146446,1.0753422538446715,1.0760171747746983,1.076692095704725,1.077367016634752,1.0780419375647787,1.0787168584948057,1.0793917794248324,1.0800667003548592,1.0807416212848862,1.081416542214913,1.0820914631449396,1.0827663840749666,1.0834413050049934,1.08411622593502,1.084791146865047,1.0854660677950738,1.0861409887251006,1.0868159096551275,1.0874908305851543,1.088165751515181,1.088840672445208,1.0895155933752347,1.0901905143052615,1.0908654352352884,1.0915403561653152,1.092215277095342,1.092890198025369,1.0935651189553957,1.0942400398854226,1.0949149608154494,1.0955898817454761,1.096264802675503,1.0969397236055298,1.0976146445355566,1.0982895654655835,1.0989644863956103,1.099639407325637,1.100314328255664,1.1009892491856907,1.1016641701157175,1.1023390910457445,1.1030140119757712,1.103688932905798,1.104363853835825,1.1050387747658517,1.1057136956958784,1.1063886166259054,1.1070635375559321,1.1077384584859589,1.1084133794159858,1.1090883003460126,1.1097632212760393,1.1104381422060663,1.111113063136093,1.11178798406612,1.1124629049961468,1.1131378259261735,1.1138127468562005,1.1144876677862272,1.115162588716254,1.115837509646281,1.1165124305763077,1.1171873515063344,1.1178622724363614,1.1185371933663881,1.1192121142964149,1.1198870352264418,1.1205619561564686,1.1212368770864953,1.1219117980165223,1.122586718946549,1.1232616398765758,1.1239365608066028,1.1246114817366295,1.1252864026666562,1.1259613235966832,1.12663624452671,1.127311165456737,1.1279860863867637,1.1286610073167904,1.1293359282468174,1.1300108491768441,1.1306857701068709,1.1313606910368978,1.1320356119669246,1.1327105328969513,1.1333854538269783,1.134060374757005,1.1347352956870318,1.1354102166170588,1.1360851375470855,1.1367600584771123,1.1374349794071392,1.138109900337166,1.1387848212671927,1.1394597421972197,1.1401346631272464,1.1408095840572732,1.1414845049873001,1.1421594259173269,1.1428343468473539,1.1435092677773806,1.1441841887074073,1.1448591096374343,1.145534030567461,1.1462089514974878,1.1468838724275148,1.1475587933575415,1.1482337142875683,1.1489086352175952,1.149583556147622,1.1502584770776487,1.1509333980076757,1.1516083189377024,1.1522832398677292,1.1529581607977561,1.153633081727783,1.1543080026578096,1.1549829235878366,1.1556578445178634,1.15633276544789,1.157007686377917,1.1576826073079438,1.1583575282379706,1.1590324491679975,1.1597073700980243,1.1603822910280512,1.161057211958078,1.1617321328881047,1.1624070538181317,1.1630819747481584,1.1637568956781852,1.1644318166082122,1.165106737538239,1.1657816584682656,1.1664565793982926,1.1671315003283194,1.167806421258346,1.168481342188373,1.1691562631183998,1.1698311840484266,1.1705061049784535,1.1711810259084803,1.171855946838507,1.172530867768534,1.1732057886985607,1.1738807096285875,1.1745556305586144,1.1752305514886412,1.1759054724186682,1.176580393348695,1.1772553142787217,1.1779302352087486,1.1786051561387754,1.1792800770688021,1.179954997998829,1.1806299189288558,1.1813048398588826,1.1819797607889095,1.1826546817189363,1.183329602648963,1.18400452357899,1.1846794445090167,1.1853543654390435,1.1860292863690705,1.1867042072990972,1.187379128229124,1.188054049159151,1.1887289700891777,1.1894038910192044,1.1900788119492314,1.1907537328792581,1.1914286538092849,1.1921035747393118,1.1927784956693386,1.1934534165993655,1.1941283375293923,1.194803258459419,1.195478179389446,1.1961531003194728,1.1968280212494995,1.1975029421795265,1.1981778631095532,1.19885278403958,1.199527704969607,1.2002026258996337,1.2008775468296604,1.2015524677596874,1.2022273886897141,1.2029023096197409,1.2035772305497678,1.2042521514797946,1.2049270724098213,1.2056019933398483,1.206276914269875,1.2069518351999018,1.2076267561299288,1.2083016770599555,1.2089765979899825,1.2096515189200092,1.210326439850036,1.211001360780063,1.2116762817100897,1.2123512026401164,1.2130261235701434,1.2137010445001701,1.2143759654301969,1.2150508863602238,1.2157258072902506,1.2164007282202773,1.2170756491503043,1.217750570080331,1.2184254910103578,1.2191004119403848,1.2197753328704115,1.2204502538004383,1.2211251747304652,1.221800095660492,1.2224750165905187,1.2231499375205457,1.2238248584505724,1.2244997793805994,1.2251747003106261,1.2258496212406529,1.2265245421706799,1.2271994631007066,1.2278743840307333,1.2285493049607603,1.229224225890787,1.2298991468208138,1.2305740677508408,1.2312489886808675,1.2319239096108943,1.2325988305409212,1.233273751470948,1.2339486724009747,1.2346235933310017,1.2352985142610284,1.2359734351910552,1.2366483561210821,1.237323277051109,1.2379981979811356,1.2386731189111626,1.2393480398411894,1.240022960771216,1.240697881701243,1.2413728026312698,1.2420477235612968,1.2427226444913235,1.2433975654213503,1.2440724863513772,1.244747407281404,1.2454223282114307,1.2460972491414577,1.2467721700714844,1.2474470910015112,1.2481220119315382,1.248796932861565,1.2494718537915916,1.2501467747216186,1.2508216956516454,1.251496616581672,1.252171537511699,1.2528464584417258,1.2535213793717526,1.2541963003017795,1.2548712212318063,1.255546142161833,1.25622106309186,1.2568959840218867,1.2575709049519137,1.2582458258819404,1.2589207468119672,1.2595956677419942,1.260270588672021,1.2609455096020477,1.2616204305320746,1.2622953514621014,1.2629702723921281,1.263645193322155,1.2643201142521818,1.2649950351822086,1.2656699561122355,1.2663448770422623,1.267019797972289,1.267694718902316,1.2683696398323427,1.2690445607623695,1.2697194816923965,1.2703944026224232,1.27106932355245,1.271744244482477,1.2724191654125037,1.2730940863425306,1.2737690072725574,1.2744439282025841,1.275118849132611,1.2757937700626378,1.2764686909926646,1.2771436119226915,1.2778185328527183,1.278493453782745,1.279168374712772,1.2798432956427988,1.2805182165728255,1.2811931375028525,1.2818680584328792,1.282542979362906,1.283217900292933,1.2838928212229597,1.2845677421529864,1.2852426630830134,1.2859175840130401,1.2865925049430669,1.2872674258730938,1.2879423468031206,1.2886172677331473,1.2892921886631743,1.289967109593201,1.290642030523228,1.2913169514532548,1.2919918723832815,1.2926667933133085,1.2933417142433352,1.294016635173362,1.294691556103389,1.2953664770334157,1.2960413979634424,1.2967163188934694,1.2973912398234961,1.2980661607535229,1.2987410816835498,1.2994160026135766,1.3000909235436033,1.3007658444736303,1.301440765403657,1.3021156863336838,1.3027906072637108,1.3034655281937375,1.3041404491237643,1.3048153700537912,1.305490290983818,1.306165211913845,1.3068401328438717,1.3075150537738984,1.3081899747039254,1.3088648956339521,1.3095398165639789,1.3102147374940059,1.3108896584240326,1.3115645793540593,1.3122395002840863,1.312914421214113,1.3135893421441398,1.3142642630741668,1.3149391840041935,1.3156141049342203,1.3162890258642472,1.316963946794274,1.3176388677243007,1.3183137886543277,1.3189887095843544,1.3196636305143812,1.3203385514444081,1.321013472374435],"scale":false,"gridIndex":0,"minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":30,"silent":true,"type":"category"}],"ec_charttype":"xy plot","series":[{"name":"Series 1","yAxisIndex":0,"areaStyle":{},"xAxisIndex":0,"smooth":false,"data":[0.0002997294860869193,0.00030111967300017195,0.00030270438676982536,0.00030448456676257507,0.00030646124526867435,0.00030863554791327186,0.00031100869409228515,0.00031358199743647397,0.0003163568662973848,0.00031933480426327154,0.00032251741069733164,0.00032590638130358673,0.00032950350871863154,0.0003333106831291399,0.0003373298929167934,0.0003415632253255252,0.0003460128671599616,0.0003506811055061787,0.00035557032848221315,0.0003606830260107774,0.00036602179062250606,0.00037158931828451536,0.00037738840925194417,0.00038342196895313485,0.0003896930088950201,0.00039620464759793084,0.00040296011155749323,0.0004099627362333935,0.00041721596706245645,0.00042472336050292103,0.0004324885851013649,0.00044051542258960463,0.00044880776900765515,0.00045736963585301174,0.0004662051512584267,0.0004753185611946695,0.00048471423070388375,0.0004943966451566272,0.0005043704115378113,0.0005146402597601615,0.000525211044003205,0.0005360877440826056,0.0005472754668433728,0.0005587794475818524,0.0005706050514962986,0.0005827577751617297,0.000595243248036708,0.0006080672339912364,0.0006212356328673639,0.0006347544820649968,0.0006486299581545223,0.0006628683785173776,0.0006774762030138416,0.0006924600356781017,0.0007078266264402312,0.0007235828728752204,0.0007397358219805375,0.0007562926719784265,0.0007732607741463698,0.0007906476346762822,0.0008084609165583505,0.0008267084414916651,0.0008453981918233287,0.0008645383125136345,0.0008841371131277087,0.0009042030698533238,0.000924744827546474,0.0009457712018021286,0.0009672911810528623,0.0009893139286911018,0.001011848785221356,0.00103490527043347,0.0010584930856067307,0.0010826221157367519,0.0011073024317884497,0.001132544292975754,0.0011583581490637596,0.0011847546426995773,0.0012117446117661315,0.0012393390917620067,0.0012675493182024364,0.0012963867290508718,0.00132586296716964,0.001355989882795769,0.001386779536043388,0.0014182441994260372,0.001450396360404442,0.0014832487239578099,0.0015168142151769093,0.0015511059818791792,0.0015861373972497345,0.0016219220624989691,0.0016584738095480334,0.0016958067037310745,0.0017339350465219033,0.0017728733782792147,0.001812636481013874,0.0018532393811773462,0.001894697352466862,0.0019370259186534122,0.001980240856428686,0.0020243581982677117,0.002069394235314617,0.002115365520282464,0.0021622888703736187,0.0022101813702153084,0.0022590603748136734,0.00230894351252163,0.002359848688028285,0.002411794085355537,0.0024647981708775663,0.002518879696349549,0.0025740577019534167,0.002630351519355964,0.002687780774778492,0.0027463653920832,0.0028061255958656828,0.002867081914564376,0.0029292551835754105,0.002992666548383871,0.003057337467698276,0.0031232897165975465,0.0031905453896871605,0.0032591269042598903,0.00332905700346596,0.003400358759488298,0.0034730555767256283,0.003547171194976731,0.0036227296926325397,0.0036997554898719337,0.003778273351856376,0.0038583083919298405,0.00393988607482236,0.004023032219847969,0.0041077730041067795,0.004194134965686103,0.004282145006857946,0.004371830397273707,0.004463218777158648,0.004556338160496137,0.004651216938213881,0.004747883881356704,0.004846368144259025,0.00494669926770272,0.005048907182073334,0.005153022210500069,0.005259075071987834,0.005367096884539124,0.00547711916825909,0.005589173848450854,0.005703293258693343,0.005819510143905374,0.005937857663391374,0.006058369393869778,0.006181079332482464,0.006306021899784547,0.0064332319427132245,0.006562744737532489,0.006694595992757582,0.006828821852052427,0.006965458897102095,0.0071045441504603984,0.007246115078365992,0.007390209593531372,0.007536866057903366,0.007686123285388452,0.007838020544547464,0.007992597561255532,0.008149894521326709,0.008309952073104768,0.008472811330010946,0.00863851387305696,0.008807101753317295,0.008978617494356467,0.009153104094618475,0.009330605029767347,0.00951116425498423,0.009694826207218898,0.009881635807388808,0.010071638462532742,0.010264880067911972,0.010461407009057455,0.010661266163764532,0.010864504904034442,0.011071171097954788,0.011281313111525276,0.01149497981042355,0.011712220561709896,0.011933085235469237,0.012157624206388204,0.01238588835527199,0.012617929070488712,0.012853798249348153,0.013093548299412797,0.013337232139733868,0.01358490320201873,0.013836615431722751,0.014092423289065764,0.014352381749970916,0.014616546306927394,0.014884972969770677,0.015157718266384651,0.015434839243317552,0.015716393466316092,0.01600243902077235,0.016293034512085844,0.016588239065933208,0.016888112328452096,0.01719271446632893,0.01750210616679765,0.017816348637541363,0.018135503606499015,0.018459633321574576,0.01878880055024683,0.019123068579078806,0.019462501213127564,0.019807162775246703,0.020157118105287322,0.020512432559193203,0.020873172007986524,0.02123940283664555,0.021611191942872615,0.021988606735750788,0.022371715134284834,0.022760585565832464,0.02315528696441682,0.02355588876892084,0.023962460921166467,0.024375073863873317,0.024793798538495282,0.025218706382935205,0.025649869329138278,0.026087359800558207,0.026531250709497425,0.026981615454324676,0.02743852791655864,0.027902062457824034,0.02837229391668067,0.02884929760531675,0.029333149306109557,0.02982392526805651,0.03032170220306614,0.03082655728211703,0.03133856813127742,0.03185781282759034,0.03238436989481566,0.032918318299035784,0.03345973744411962,0.034008707167045196,0.03456530773308032,0.03512961983081908,0.035701724567076876,0.036281703461639114,0.036869638441864735,0.03746561183714407,0.03806970637321053,0.03868200516630531,0.039302591717193414,0.039931549905032476,0.040568963981090944,0.04121491856232028,0.04186949862477564,0.04253278949688394,0.04320487685256813,0.04388584670421343,0.04457578539548865,0.045274779594011896,0.04598291628386823,0.04670028275797422,0.04742696661028964,0.04816305572788275,0.048908638282835454,0.049663802724006695,0.050428637768635085,0.051203232393797274,0.05198767582771144,0.05278205754088952,0.05358646723714357,0.05440099484443177,0.05522573050556698,0.05606076456876613,0.05690618757805435,0.05776209026351867,0.05862856353141732,0.05950569845413767,0.060393586260008736,0.0612923183229675,0.06220198615208089,0.06312268138092333,0.06405449575680795,0.06499752112987908,0.06595184944206094,0.0669175727158651,0.06789478304306128,0.0688835725732057,0.06988403350203727,0.07089625805973214,0.0719203384990295,0.0729563670832205,0.07400443607400628,0.07506463771922527,0.07613706424045404,0.07722180782047845,0.07831896059064031,0.0794286146180609,0.08055086189274129,0.08168579431454398,0.08283350368005493,0.08399408166933092,0.08516761983253054,0.08635420957643475,0.08755394215085627,0.08876690863494197,0.08999319992336816,0.09123290671243406,0.09248611948605298,0.09375292850164527,0.0950334237759354,0.0963276950706532,0.09763583187814814,0.09895792340691188,0.10029405856701368,0.1016443259554567,0.10300881384145173,0.10438761015161206,0.10578080245507726,0.10718847794856155,0.1086107234413357,0.11004762534014316,0.11149926963405295,0.11296574187925258,0.11444712718378769,0.11594351019224347,0.11745497507038347,0.118981605489735,0.12052348461213662,0.12208069507424342,0.1236533189719979,0.12524143784506828,0.1268451326612556,0.12846448380087924,0.13009957104113792,0.13175047354045286,0.13341726982280055,0.13510003776202892,0.1367988545661718,0.13851379676175996,0.14024494017812986,0.14199235993174356,0.14375613041051036,0.14553632525812818,0.147333017358438,0.1491462788198002,0.15097618095949758,0.15282279428816548,0.15468618849425658,0.15656643242854404,0.15846359408866514,0.16037774060371018,0.16230893821886577,0.16425725228010613,0.16622274721894997,0.16820548653727596,0.17020553279220602,0.17222294758106266,0.17425779152639992,0.1763101242611162,0.17838000441365037,0.1804674895932695,0.18257263637544585,0.18469550028733678,0.1868361357933619,0.1889945962808915,0.19117093404604174,0.19336520027958648,0.19557744505299224,0.19780771730457097,0.2000560648257656,0.20232253424756758,0.20460717102707046,0.20691001943416648,0.2092311225383858,0.21157052219589031,0.21392825903661636,0.21630437245158132,0.2186989005803483,0.22111188029866147,0.22354334720624874,0.22599333561480422,0.2284618785361462,0.23094900767055906,0.23345475339532656,0.23597914475345091,0.23852220944257255,0.2410839738040854,0.24366446281245757,0.24626370006476037,0.24888170777040564,0.25151850674109966,0.2541741163810144,0.25684855467718437,0.25954183819012333,0.26225398204467665,0.2649849999211024,0.26773490404639,0.27050370518581984,0.27329141263476364,0.2760980342107338,0.2789235762456796,0.28176804357853824,0.2846314395480395,0.287513765985772,0.2904150232095086,0.29333521001679597,0.29627432367881434,0.29923235993450426,0.30220931298496634,0.30520517548813764,0.308219938553744,0.3112535917385323,0.31430612304178596,0.31737751890112326,0.32046776418858275,0.32357684220699734,0.32670473468665817,0.3298514217822703,0.33301688207020336,0.3362010925460356,0.33940402862239755,0.34262566412711204,0.34586597130163343,0.34912492079979046,0.3524024816868283,0.35569862143875497,0.3590133059419912,0.3623464994933255,0.3656981648001736,0.3690682629811457,0.3724567535669174,0.37586359450140944,0.37928874214327507,0.3827321512676907,0.38619377506845987,0.3896735651604172,0.3931714715821451,0.3966874427989934,0.40022142570640573,0.4037733656335527,0.4073432063472675,0.410930890056288,0.4145363574157995,0.41815954753228035,0.4218003979686498,0.42545884474971135,0.42913482236789935,0.4328282637893182,0.43653910046007727,0.44026726231292035,0.44401267777414455,0.4477752737708097,0.4515549757382336,0.45535170762777255,0.4591653919148843,0.4629959496074719,0.4668433002545023,0.4707073619549019,0.47458805136672244,0.47848528371657595,0.48239897280933564,0.48632903103809844,0.4902753693944063,0.4942378974787248,0.4982165235111723,0.5022111543424966,0.5062216954652994,0.5102480510254975,0.5142901238340235,0.5183478153787574,0.5224210258366877,0.5265096540862947,0.5306135977201556,0.5347327530577622,0.5388670151585513,0.5430162778351375,0.5471804336667512,0.5513593740128668,0.5555529890270261,0.5597611676708449,0.5639837977282016,0.5682207658195985,0.5724719574166935,0.5767372568569986,0.5810165473587318,0.5853097110358254,0.5896166289130811,0.5939371809414651,0.5982712460135378,0.6026187019790155,0.6069794256604528,0.6113532928690445,0.6157401784205347,0.6201399561512351,0.6245524989341379,0.6289776786951233,0.6334153664292516,0.637865432217133,0.6423277452413728,0.6468021738030798,0.6512885853384368,0.6557868464353203,0.6602968228499693,0.6648183795236917,0.6693513805996052,0.673895689439399,0.6784511686401209,0.6830176800509711,0.6875950847901038,0.6921832432614272,0.6967820151713913,0.701391259545766,0.7060108347463914,0.7106405984879016,0.715280407854411,0.7199301193161585,0.7245895887460991,0.7292586714364421,0.7339372221151222,0.7386250949622006,0.7433221436261909,0.7480282212402954,0.7527431804385567,0.7574668733719053,0.7621991517241057,0.7669398667275917,0.7716888691791808,0.7764460094556662,0.7812111375292781,0.7859841029830041,0.7907647550257699,0.7955529425074658,0.8003485139338193,0.8051513174811017,0.8099612010106692,0.8147780120833245,0.8196015979735021,0.8244318056832606,0.8292684819560879,0.8341114732905033,0.8389606259534568,0.8438157859935179,0.8486767992538498,0.8535435113849615,0.8584157678572362,0.8632934139732236,0.8681762948797017,0.8730642555794941,0.8779571409430414,0.8828547957197225,0.8877570645489214,0.8926637919708337,0.8975748224370078,0.902490000320621,0.907409169926481,0.9123321755007535,0.9172588612404071,0.922189071302379,0.9271226498124504,0.9320594408738347,0.9369992885754704,0.9419420370000195,0.9468875302315671,0.9518356123630173,0.9567861275031895,0.9617389197836033,0.9666938333649584,0.9716507124433037,0.9766094012558941,0.9815697440867318,0.986531585271795,0.9914947692039485,0.9964591403375385,1.0014245431926647,1.0063908223591398,1.0113578225001238,1.016325388355441,1.021293364744575,1.0262615965693465,1.031229928816269,1.036198206558585,1.0411662749579844,1.046133979266004,1.0511011648251118,1.0560676770694728,1.0610333615254035,1.0659980638115103,1.0709616296385198,1.0759239048087998,1.0808847352155713,1.0858439668418185,1.0908014457588964,1.0957570181248388,1.1007105301823716,1.1056618282566322,1.1106107587525997,1.1155571681522394,1.1205009030113662,1.1254418099562287,1.1303797356798189,1.1353145269379157,1.1402460305448587,1.145174093369066,1.1500985623282942,1.1550192843846494,1.1599361065393525,1.1648488758272675,1.1697574393111925,1.1746616440759259,1.1795613372221099,1.1844563658598593,1.1893465771021794,1.1942318180581837,1.1991119358261138,1.2039867774861726,1.2088561900931738,1.2137200206690186,1.2185781161950047,1.2234303236039747,1.2282764897723157,1.2331164615118109,1.2379500855613599,1.2427772085785687,1.2475976771312192,1.2524113376886319,1.257218036612922,1.262017620150166,1.2668099344214796,1.2715948254140232,1.2763721389719385,1.28114172078723,1.2859034163905962,1.2906570711422245,1.2954025302225534,1.3001396386230213,1.3048682411367996,1.3095881823495288,1.3142993066300652,1.3190014581212466,1.323694480730688,1.3283782181216204,1.3330525137037743,1.3377172106243311,1.3423721517589409,1.3470171797028232,1.35165213676196,1.356276864944392,1.3608912059516252,1.3654950011701645,1.3700880916631795,1.3746703181623157,1.3792415210596594,1.3838015403998725,1.3883502158724992,1.3928873868044638,1.3974128921527647,1.4019265704973758,1.406428260034371,1.410917798569273,1.4153950235106465,1.4198597718639405,1.4243118802255932,1.4287511847774037,1.4331775212811941,1.4375907250737558,1.4419906310621033,1.4463770737190387,1.45074988707904,1.4551089047344816,1.4594539598321972,1.463784885070398,1.4681015126959485,1.4724036745020204,1.4766912018261225,1.4809639255485252,1.4852216760910841,1.4894642834164733,1.4936915770278365,1.4979033859688662,1.50209953882432,1.5062798637209793,1.5104441883290647,1.5145923398641084,1.5187241450893014,1.5228394303183137,1.5269380214186041,1.5310197438152184,1.5350844224950935,1.5391318820118636,1.543161946491186,1.5471744396365845,1.5511691847358247,1.5551460046678187,1.559104721910077,1.5630451585467027,1.5669671362769375,1.5708704764242698,1.5747549999461026,1.5786205274439913,1.5824668791744538,1.5862938750603586,1.590101334702894,1.5938890773941266,1.5976569221301442,1.6014046876247972,1.6051321923240316,1.6088392544208276,1.6125256918707342,1.6161913224080142,1.6198359635623891,1.6234594326764005,1.6270615469233767,1.6306421233260115,1.6342009787755583,1.6377379300516335,1.6412527938426376,1.6447453867667856,1.648215525393756,1.65166302626695,1.6550877059263618,1.6584893809320633,1.6618678678882977,1.6652229834681784,1.668554544438999,1.6718623676881408,1.6751462702495865,1.6784060693310299,1.6816415823415793,1.6848526269200543,1.6880390209638658,1.6912005826584848,1.6943371305074844,1.697448483363157,1.7005344604576993,1.703594881434961,1.7066295663827498,1.7096383358656864,1.7126210109586029,1.7155774132804833,1.7185073650289269,1.7214106890151397,1.724287208699441,1.7271367482272721,1.7299591324657113,1.7327541870404715,1.7355217383733823,1.7382616137203455,1.7409736412097485,1.7436576498813332,1.746313469725507,1.7489409317230824,1.7515398678854408,1.7541101112951045,1.7566514961467081,1.7591638577883553,1.7616470327633509,1.7641008588522982,1.7665251751155435,1.7689198219359592,1.7712846410620513,1.773619475651382,1.7759241703142823,1.7781985711578567,1.7804425258302548,1.7826558835651982,1.7848384952267495,1.7869902133543087,1.7891108922078223,1.7912003878131852,1.7932585580078297,1.7952852624864757,1.797280362847033,1.7992437226366373,1.801175207397804,1.8030746847146832,1.8049420242594008,1.8067770978384663,1.8085797794392326,1.8103499452763927,1.812087473838488,1.8137922459344198,1.8154641447399458,1.8171030558441346,1.818708867295773,1.8202814696496987,1.8218207560130457,1.8233266220913824,1.8247989662347228,1.826237689483397,1.827642695613756,1.8290138911836984,1.8303511855779981,1.8316544910534134,1.832923722783559,1.8341587989035244,1.8353596405542176,1.8365261719264176,1.837658320304511,1.838756016109905,1.839819192944085,1.8408477876313085,1.8418417402609093,1.8428009942291963,1.843725496280931,1.844615196550356,1.8454700486017679,1.8462900094696022,1.8470750396980244,1.847825103380003,1.8485401681958404,1.849220205451155,1.849865190114288,1.8504751008531148,1.851049920071254,1.8515896339436402,1.852094232451459,1.8525637094164118,1.8529980625343025,1.8533972934079266,1.8537614075792412,1.8540904145608015,1.8543843278664527,1.8546431650412445,1.8548669476905701,1.855055701508502,1.855209456305308,1.8553282460341403,1.8554121088168674,1.8554610869690493,1.8554752270240278,1.855454579756124,1.8553992002029223,1.8553091476866341,1.855184485834517,1.8550252825983438,1.8548316102729023,1.8546035455135141,1.8543411693525582,1.8540445672149861,1.85371382893282,1.8533490487586104,1.8529503253778579,1.8525177619203679,1.8520514659705452,1.8515515495766002,1.851018129258673,1.8504513260158482,1.8498512653320618,1.8492180771808853,1.8485518960291807,1.847852860839612,1.847121115072009,1.8463568066835754,1.8455600881279277,1.8447311163529634,1.8438700527975485,1.8429770633870173,1.842052318527477,1.8410959930989148,1.8401082664470967,1.839089322374257,1.8380393491285716,1.83695853939241,1.8358470902693649,1.83470520327005,1.8335330842966708,1.8323309436263582,1.8310989958932682,1.829837460069439,1.8285465594444137,1.8272265216036168,1.8258775784054924,1.8244999659573986,1.8230939245902629,1.8216596988319926,1.8201975373796482,1.8187076930703774,1.8171904228511158,1.8156459877470463,1.8140746528288365,1.8124766871786433,1.810852363854892,1.8092019598558418,1.8075257560819313,1.8058240372969157,1.804097092087799,1.8023452128235702,1.8005686956127456,1.7987678402597245,1.796942950219972,1.7950943325540278,1.7932222978803551,1.7913271603270349,1.7894092374823196,1.7874688503440486,1.7855063232679402,1.783521983914771,1.7815161631964507,1.7794891952210041,1.7774414172364723,1.7753731695737491,1.773284795588356,1.7711766416011756,1.7690490568381583,1.7669023933690082,1.7647370060448695,1.7625532524350234,1.7603514927626145,1.7581320898394142,1.7558954089996495,1.7536418180328996,1.7513716871160834,1.749085388744557,1.7467832976623323,1.7444657907914363,1.742133247160433,1.739786047832119,1.737424575830416,1.7350492160664774,1.7326603552640298,1.7302583818839647,1.727843686048204,1.7254166594628602,1.7229776953407057,1.720527188322979,1.7180655344005424,1.7155931308344177,1.7131103760757187,1.7106176696850002,1.7081154122510498,1.7056040053091426,1.703083851258781,1.7005553532809397,1.6980189152548482,1.695474941674319,1.6929238375636606,1.6903660083931862,1.6878018599943512,1.6852317984745342,1.6826562301314951,1.680075561367528,1.6774901986033357,1.67490054819165,1.6723070163306215,1.6697100089770058,1.667109931759171,1.6645071898899473,1.6619021880793499,1.6592953304471962,1.6566870204356452,1.6540776607216827,1.6514676531295773,1.648857398543337,1.6462472968191868,1.643637746698095,1.641029145718376,1.6384218901283916,1.6358163747993784,1.633212993138429,1.6306121370016469,1.6280141966075101,1.6254195604504582,1.6228286152147369,1.6202417456885234,1.617659334678356,1.6150817629238958,1.612509409013045,1.609942649297448,1.6073818578084,1.6048274061731884,1.6022796635318903,1.599738996454656,1.5972057688594987,1.594680341930615,1.592163074037266,1.5896543206532376,1.587154434276906,1.5846637643519352,1.5821826571886295,1.5797114558859584,1.5772505002542883,1.5748001267388358,1.5723606683438727,1.5699324545576945,1.5675158112783911,1.5651110607404282,1.562718521442067,1.5603385080736492,1.5579713314467567,1.5556172984242815,1.5532767118514172,1.5509498704875961,1.5486370689393967,1.5463385975944293,1.5440547425562399,1.5417857855802313,1.5395320040106364,1.5372936707185525,1.5350710540410615,1.5328644177214532,1.5306740208505678,1.528500117809277,1.5263429582121213,1.5242027868521197,1.5220798436467675,1.519974363585244,1.517886576676836,1.515816707900602,1.5137649771562887,1.511731599216514,1.5097167836802312,1.507720734927487,1.5057436520754923,1.503785728936011,1.5018471539740863,1.4999281102681117,1.4980287754712622,1.496149321774296,1.4942899158697358,1.492450718917444,1.490631886511597,1.4888335686490737,1.4870559096992628,1.4852990483752995,1.4835631177067417,1.4818482450136896,1.4801545518823596,1.478482154142117,1.4768311618439744,1.475201679240566,1.4735938047675925,1.4720076310267571,1.470443244770182,1.4689007268863188,1.4673801523873555,1.4658815903981182,1.4644051041464758,1.4629507509552468,1.4615185822356118,1.4601086434820278,1.4587209742686555,1.4573556082472883,1.4560125731467886,1.454691890774031,1.4533935770163517,1.4521176418454962,1.4508640893230735,1.4496329176075031,1.4484241189624625,1.4472376797668214,1.446073580526068,1.4449317958852155,1.4438122946431868,1.4427150397686739,1.441639988417462,1.440587091951217,1.4395562959577237,1.4385475402725707,1.437560759002278,1.4365958805488501,1.435652827635755,1.4347315173353132,1.4338318610974945,1.4329537647801025,1.4320971286803488,1.4312618475677945,1.430447810718658,1.429654901951467,1.4288829996640533,1.428131976871871,1.4274017012476277,1.426692035162213,1.4260028357269159,1.4253339548369128,1.424685239216014,1.424056530462648,1.4234476650970806,1.4228584746098416,1.422288785511349,1.421738419382712,1.421207192927699,1.4206949180258528,1.4202014017867337,1.4197264466052752,1.419269850218233,1.4188314057617113,1.418410901829746,1.4180081225339258,1.4176228475640338,1.4172548522496886,1.4169039076229668,1.4165697804819857,1.4162522334554255,1.4159510250679743,1.4156659098066706,1.4153966381881222,1.4151429568265894,1.414904608502895,1.4146813322341567,1.414472863344307,1.4142789335353878,1.4140992709595872,1.413933600292011,1.413781642804151,1.4136431164380343,1.413517735881036,1.4134052126413212,1.4133052551239005,1.4132175687072743,1.4131418558206426,1.413077816021654,1.413025146074675,1.4129835400295512,1.4129526893008402,1.4129322827474884,1.4129220067529333,1.4129215453056012,1.4129305800797776,1.4129487905168316,1.4129758539067623,1.4130114454700464,1.4130552384397645,1.4131069041439792,1.4131661120883405,1.4132325300388944,1.4133058241050747,1.4133856588228468,1.4134716972379828,1.4135636009894448,1.4136610303928485,1.4137636445239894,1.4138711013023968,1.4139830575749048,1.414099169199206,1.4142190911273684,1.4143424774892905,1.414468981676073,1.414598256423281,1.4147299538940747,1.4148637257621846,1.4149992232947073,1.4151360974347031,1.415273998883566,1.415412578183148,1.4155514857976128,1.4156903721950003,1.4158288879284722,1.415966683717226,1.4161034105270474,1.4162387196504844,1.4163722627866204,1.4165036921204228,1.4166326604016501,1.4167588210232955,1.4168818280995414,1.4170013365432126,1.417117002142702,1.4172284816383551,1.417335432798281,1.4174375144935902,1.4175343867730217,1.4176257109369506,1.4177111496107557,1.4177903668175291,1.4178630280501057,1.417928800342405,1.417987352340056,1.4180383543702941,1.4180814785111173,1.4181163986596759,1.4181427905998878,1.4181603320692582,1.4181687028248933,1.4181675847086872,1.4181566617116725,1.4181356200375186,1.4181041481651597,1.4180619369105436,1.4180086794874915,1.4179440715676406,1.4178678113394758,1.4177795995664266,1.4176791396440187,1.4175661376560724,1.417440302429932,1.4173013455907209,1.4171489816146048,1.4169829278810626,1.4168029047241433,1.41660863548271,1.4163998465496581,1.4161762674200962,1.4159376307384879,1.4156836723447415,1.4154141313192419,1.4151287500268173,1.4148272741596366,1.4145094527790276,1.4141750383562113,1.4138237868119483,1.413455457555093,1.4130698135200432,1.412666621203095,1.4122456506976828,1.4118066757285157,1.4113494736845957,1.4108738256511222,1.410379516440276,1.409866334620884,1.409334072546962,1.4087825263851337,1.4082114961409236,1.4076207856839278,1.407010202771858,1.406379559073463,1.4057286701903238,1.405057355677528,1.4043654390632203,1.403652747867036,1.4029191136174144,1.4021643718677994,1.4013883622117242,1.4005909282967908,1.3997719178375414,1.398931182627227,1.3980685785484832,1.3971839655829048,1.396277207819542,1.395348173462305,1.3943967348362962,1.3934227683930693,1.3924261547148222,1.3914067785175326,1.3903645286530404,1.3892992981100858,1.3882109840143084,1.387099487627218,1.3859647143441436,1.384806573691166,1.3836249793210502,1.3824198490081767,1.381191104642488,1.3799386722224594,1.3786624818470976,1.3773624677069831,1.3760385680743668,1.3746907252923242,1.3733188857629877,1.3719229999348588,1.3705030222892194,1.3690589113256428,1.3675906295466325,1.3660981434413801,1.3645814234686726,1.3630404440389485,1.3614751834955243,1.359885624094996,1.358271751986832,1.356633557192175,1.354971033581856,1.3532841788536396,1.351572994508715,1.3498374858274451,1.3480776618443837,1.3462935353225798,1.344485122727181,1.3426524441983485,1.340795523523499,1.3389143881088903,1.3370090689505618,1.3350796006046446,1.3331260211570555,1.3311483721925943,1.3291466987634524,1.3271210493571513,1.3250714758639273,1.3229980335435727,1.3209007809917508,1.318779780105805,1.3166350960500655,1.314466797220682,1.3122749552099855,1.3100596447704052,1.3078209437779464,1.3055589331952513,1.303273697034255,1.3009653223184512,1.2986338990447863,1.296279520145194,1.2939022814477839,1.2915022816377077,1.2890796222177072,1.2866344074683664,1.284166744408079,1.2816767427527558,1.2791645148752644,1.2766301757646485,1.2740738429851097,1.2714956366347916,1.2688956793043635,1.2662740960354273,1.2636310142787641,1.260966563852424,1.2582808768996867,1.2555740878468984,1.2528463333611992,1.250097752308165,1.2473284857093616,1.2445386766998408,1.2417284704855804,1.2388980143008912,1.2360474573657927,1.2331769508433874,1.2302866477972265,1.2273767031487002,1.2244472736344503,1.221498517763827,1.2185305957763959,1.215543669599514,1.212537902805983,1.2095134605717903,1.2064705096339563,1.2034092182484926,1.2003297561484862,1.197232294502322,1.1941170058720518,1.1909840641719236,1.187833644627078,1.1846659237324326,1.1814810792117465,1.1782792899768963,1.1750607360873573,1.1718255987099089,1.1685740600785701,1.1653063034547766,1.1620225130878035,1.1587228741754527,1.1554075728250035,1.1520767960144431,1.1487307315539765,1.145369568047834,1.1419934948563788,1.138602702058522,1.1351973804144537,1.131777721328699,1.1283439168135025,1.1248961594525553,1.1214346423650592,1.1179595591701488,1.1144711039516642,1.1109694712232918,1.1074548558940727,1.1039274532342827,1.100387458841697,1.0968350686082342,1.0932704786869971,1.0896938854597011,1.0861054855045071,1.0825054755642554,1.0788940525151052,1.075271413335592,1.0716377550760918,1.0679932748287082,1.064338169697582,1.0606726367696209,1.05699687308566,1.0533110756120536,1.0496154412126923,1.0459101666214625,1.0421954484151372,1.0384714829867054,1.0347384665191433,1.0309965949596225,1.027246063994164,1.0234870690227342,1.0197198051347798,1.0159444670852151,1.0121612492708463,1.0083703457072442,1.0045719500060621,1.0007662553527945,0.9969534544849841,0.9931337396708674,0.9893073026884689,0.9854743348051306,0.9816350267574878,0.9777895687318798,0.9739381503452023,0.9700809606261913,0.9662181879971485,0.9623500202560921,0.958476644559342,0.9545982474045343,0.9507150146140593,0.946827131318923,0.9429347819430332,0.9390381501878959,0.9351374190177374,0.9312327706450283,0.927324386516424,0.923412447299104,0.9194971328675197,0.9155786222905365,0.9116570938189728,0.9077327248735265,0.9038056920330952,0.8998761710234737,0.8959443367064324,0.8920103630691718,0.8880744232141449,0.8841366893492487,0.8801973327783765,0.8762565238923242,0.8723144321600542,0.868371226120304,0.8644270733735372,0.8604821405742343,0.8565365934235161,0.8525905966620955,0.8486443140635499,0.8446979084279174,0.840751541575598,0.8368053743415691,0.8328595665699,0.8289142771085631,0.8249696638045392,0.8210258834992068,0.8170830920240131,0.8131414441964185,0.8092010938161184,0.8052621936615153,0.8013248954864671,0.7973893500172742,0.7934557069499217,0.7895241149475642,0.7855947216382433,0.7816676736128394,0.777743116423248,0.7738211945807769,0.7699020515547556,0.7659858297713558,0.7620726706126141,0.7581627144156542,0.7542561004720972,0.7503529670276646,0.7464534512819573,0.7425576893884134,0.7386658164544355,0.734777966541684,0.7308942726665281,0.7270148668006517,0.7231398798718125,0.719269441764737,0.7154036813221609,0.711542726346001,0.7076867035986529,0.7038357388044159,0.6999899566510338,0.6961494807913481,0.6923144338450631,0.6884849374006109,0.6846611120171167,0.6808430772264573,0.6770309515354118,0.6732248524278917,0.6694248963672566,0.6656311987987015,0.6618438741517182,0.6580630358426214,0.6542887962771397,0.6505212668530628,0.6467605579629455,0.6430067789968594,0.6392600383451932,0.635520443401494,0.631788100565348,0.6280631152452969,0.6243455918617826,0.620635633850124,0.6169333436635138,0.6132388227760395,0.6095521716857197,0.6058734899175552,0.602202876026593,0.5985404276009947,0.5948862412651144,0.5912404126825759,0.5876030365593486,0.5839742066468245,0.5803540157448842,0.5767425557049574,0.5731399174330714,0.5695461908928869,0.565961465108719,0.5623858281685381,0.5588193672269532,0.5552621685081724,0.5517143173089406,0.5481758980014494,0.5446469940362237,0.5411276879449731,0.537618061343421,0.5341181949340938,0.5306281685090802,0.5271480609527581,0.5236779502444802,0.5202179134612258,0.516768026780215,0.5133283654814821,0.5098990039504078,0.5064800156802141,0.5030714732744143,0.49967344844922257,0.49628601203591927,0.49290923398317427,0.489543183359325,0.4861879283546117,0.48284353628336724,0.4795100735861634,0.4761876058319106,0.4728761977199144,0.4695759130818866,0.46628681488391216,0.4630089652283699,0.4597424253558102,0.4564872556467892,0.4532435156236574,0.45001126395230606,0.446790558443871,0.44358145605639304,0.4403840128964371,0.4371982842206705,0.4340243244374007,0.4308621871080735,0.4277119249487313,0.4245735898314348,0.4214472327856471,0.4183329039995805,0.41523065282151145,0.41214052776105636,0.4090625764904187,0.4059968458456039,0.40294338182759903,0.3999022296035304,0.39687343350778603,0.39385703704311503,0.3908530828817009,0.38786161286620946,0.3848826680108147,0.38191628850220344,0.37896251370055983,0.37602138214052977,0.3730929315321713,0.3701771987618873,0.36727421989334447,0.3643840301683815,0.36150666400790327,0.35864215501276975,0.35579053596467447,0.35295183882701864,0.35012609474577905,0.34731333405037657,0.3445135862545401,0.3417268800571745,0.3389532433432269,0.336192703184563,0.3334452858408429,0.3307110167604078,0.32798992058117665,0.32528202113155114,0.3225873414313344,0.3199059036926647,0.3172377293209647,0.3145828389159069,0.3119412522724014,0.3093129883816017,0.3066980654319348,0.30409650081015527,0.3015083111024257,0.2989335120954232,0.29637211877747727,0.2938241453397368,0.2912896051773707,0.28876851089080113,0.2862608742869731,0.28376670638066104,0.28128601739581416,0.27881881676694076,0.2763651131405348,0.27392491437654576,0.2714982275498918,0.26908505895201934,0.2666854140925101,0.26429929770073446,0.26192671372755777,0.25956766534709497,0.25722215495851836,0.2548901841879195,0.25257175389022457,0.2502668641511669,0.2479755142893139,0.24569770285815648,0.24343342764825204,0.24118268568943177,0.23894547325306797,0.2367217858544014,0.23451161825493533,0.23231496446488928,0.2301318177457215,0.2279621706127132,0.22580601483762128,0.2236633414513982,0.22153414074697841,0.21941840228213325,0.21731611488239588,0.21522726664405442,0.21315184493721662,0.2110898364089432,0.20904122698645433,0.20700600188040597,0.20498414558823874,0.2029756418975992,0.2009804738898333,0.19899862394355272,0.19703007373827308,0.19507480425812818,0.1931327957956544,0.1912040279556493,0.18928847965910656,0.18738612914721925,0.18549695398546145,0.18362093106774055,0.18175803662062318,0.17990824620763518,0.17807153473363563,0.17624787644925852,0.1744372449554346,0.17263961320798052,0.17085495352225952,0.16908323757791782,0.1673244364236878,0.16557852048226498,0.1638454595552532,0.16212522282818181,0.16041777887559108,0.1587230956661847,0.1570411405680528,0.15537188035396193,0.15371528120671057,0.1520713087245525,0.15043992792668293,0.14882110325879247,0.14721479859868186,0.145620977261942,0.14403960200769306,0.14247063504438962,0.14091403803567956,0.13936977210632856,0.13783779784819838,0.13631807532628432,0.13481056408480935,0.13331522315337185,0.13183201105314932,0.1303608858031538,0.12890180492653927,0.12745472545696077,0.12601960394498116,0.1245963964645288,0.12318505861940002,0.12178554554980935,0.12039781193898233,0.1190218120197932,0.11765749958144553,0.11630482797618957,0.11496375012608484,0.11363421852979476,0.11231618526942366,0.11100960201738401,0.109714420043301,0.10843059022094897,0.10715806303521717,0.10589678858910814,0.10464671661076119,0.10340779646050585,0.10217997713793736,0.1009632072890195,0.09975743521320565,0.09856260887058688,0.0973786758890513,0.09620558357146927,0.0950432789028901,0.09389170855775482,0.09275081890712358,0.09162055602591448,0.0905008657001502,0.08939169343421942,0.08829298445813806,0.08720468373482299,0.08612673596736675,0.08505908560631587,0.08400167685694955,0.08295445368656067,0.08191735983173183,0.08089033880561229,0.0798733339051855,0.07886628821853425,0.07786914463209688,0.07688184583791347,0.07590433434086404,0.07493655246589111,0.07397844236521146,0.07302994602551359,0.07209100527513418,0.07116156179122407,0.07024155710688691,0.06933093261830495,0.0684296295918358,0.0675375891710919,0.06665475238399046,0.06578106014978094,0.06491645328604213,0.06406087251565207,0.06321425847372875,0.06237655171453675,0.06154769271836298,0.060727621898359674,0.0599162796073497,0.05911360614459572,0.05831954176253447,0.057534026673469116,0.05675700105622271,0.05598840506275127,0.05522817882471287,0.05447626245999551,0.053732596079197906,0.05299711979206685,0.052269773713886455,0.051550497971819806,0.050839232711203136,0.050135918101787996,0.04944049434393574,0.04875290167475563,0.04807308037419514,0.04740097077107465,0.04673651324906594,0.046079648252618455,0.04543031629282718,0.04478845795324224,0.04415401389562654,0.04352692486564583,0.04290713169850738,0.04229457532453357,0.04168919677467556,0.04109093718596772,0.040499737806915986,0.039915540002826225,0.03933828526106639,0.038767915196268224,0.03820437155546015,0.037647596223137,0.03709753122626332,0.03655411873921084,0.03601730108862734,0.035487020758240645,0.034963220393592745,0.034445842806705526,0.03393483098068044,0.03343012807422591,0.03293167742611729,0.03243942255958611,0.031953307186640634,0.0314732752123128,0.030999270738840956,0.030531238069773176,0.030069121714007385,0.029612866389753856,0.02916241702843292,0.02871771877849319,0.028278717009165122,0.02784535731413809,0.027417585515168513,0.026995347665612818,0.026578590053891404,0.026167259206879484,0.025761301893223634,0.025360665126589854,0.024965296168836554,0.024575142533117267,0.024190151986909894,0.023810272554976683,0.023435452522248823,0.023065640436642276,0.022700785111800334,0.022340835629766326,0.021985741343584372,0.021635451879827697,0.021289917141059767,0.02094908730822112,0.02061291284294882,0.020281344489824188,0.019954333278551367,0.019631830526065944,0.019313787838576,0.01900015711353245,0.018690890541532362,0.01838594060815478,0.018085260095725045,0.017788802085017236,0.017496519956886114,0.01720836739383433,0.016924298381510633,0.016644267210148667,0.01636822847593311,0.016096137082306672,0.015827948241210643,0.015563617474262104,0.015303100613868775,0.015046353804279211,0.014793333502573891,0.01454399647959162,0.014298299820796737,0.01405620092708737,0.013817657515538664,0.013582627620092533,0.013351069592186349,0.013122942101321297,0.01289820413557749,0.012676815002069422,0.012458734327344873,0.012243922057730339,0.012032338459620581,0.011823944119712076,0.011618699945185981,0.011416567163835364,0.011217507324141729,0.011021482295297452,0.01082845426718329,0.010638385750286278,0.010451239575577156,0.010266978894331313,0.010085567177908969,0.00990696821748037,0.009731146123709067,0.009558065326387477,0.009387690574027607,0.009219986933406435,0.009054919789067542,0.008892454842779757,0.008732558112952288,0.008575195934011001,0.008420334955728304,0.008267942142518733,0.008117984772690559,0.00797043043766113,0.007825247041131494,0.007682402798226781,0.007541866234596045,0.007403606185481665,0.007267591794746134,0.00713379251387164,0.0070021781009212,0.006872718619468268,0.006745384437494617,0.006620146226255855,0.006496974959115651,0.0063758419103512876,0.006256718653928156,0.006139577062247603,0.0060243893048652075,0.005911127847181022,0.0057997654491064865,0.005690275163702435,0.0055826303357929125,0.005476804600555982,0.0053727718820881926,0.005270506391948621,0.005169982627678593,0.005071175371301001,0.004974059687799487,0.0048786109235736536,0.0047848047048796305,0.004692616936248742,0.00460202379888823,0.004513001749063605,0.004425527516467978,0.004339578102570768,0.0042551307789523984,0.0041721630856244585,0.004090652829333893,0.004010578081857938,0.003931917178279051,0.0038546487152537195,0.0037787515492666984,0.0037042047948725454,0.003630987822930559,0.0035590802588266746,0.003488461980685739,0.0034191131175780876,0.003351014047713499,0.0032841453966319517,0.003218488035384451,0.0031540230787074353,0.0030907318831923936,0.003028596045450929,0.002967597400271152,0.0029077180187741802,0.002848940206564593,0.002791246501878064,0.0027346196737257633,0.002679042720036842,0.0026244988658014057,0.0025709715612080436,0.0025184444797836797,0.0024669015165332403,0.0024163267860776716,0.002366704620794316,0.0023180195689591204,0.0022702563928876235,0.0022234000670815768,0.0021774357763754137,0.002132348914088117,0.002088125080175224,0.002044750079389937,0.0020022099194422494,0.001960490809168741,0.0019195791567027248,0.001879461567654242,0.00184012484329113,0.001801555978732397,0.0017637421611427229,0.0017266707679371163,0.0016903293649930817,0.0016547057048700436,0.0016197877250354181,0.0015855635461030637,0.0015520214700772555,0.001519149978607262,0.0014869377312516918,0.0014553735637522491,0.0014244464863184814,0.0013941456819223652,0.001364460504603926,0.0013353804777891248,0.0013068952926178906,0.0012789948062840728,0.001251669040389508,0.001224908179307066,0.0011987025685592512,0.0011730427132094906,0.0011479192762640367,0.0011233230770916064,0.0010992450898524853,0.0010756764419446174,0.0010526084124633794,0.0010300324306743852,0.0010079400745017925,0.0009863230690345809,0.000965173285041851,0.0009444827375098691,0.0009242435841903124,0.0009044481241674424,0.0008850887964391291,0.0008661581785147643,0.0008476489850321733,0.0008295540663861845,0.0008118664073795551,0.0007945791258862495,0.0007776854715371706,0.0007611788244173273,0.0007450526937858165,0.0007293007168114873,0.0007139166573262301,0.0006988944045968198,0.0006842279721158695,0.0006699114964111436,0.0006559392358716915,0.0006423055695955748,0.0006290049962552474,0.0006160321329813159,0.0006033817142668124,0.0005910485908907775,0.0005790277288604956,0.0005673142083754829,0.0005559032228075328,0.0005447900777054218,0.0005339701898168028,0.0005234390861301938,0.0005131924029399687,0.000503225884927766,0.0004935353842682663,0.000484116859754434,0.0004749663759437833,0.00046608010232280367,0.0004574543124983149,0.00044908538340503873,0.00044096979453529805,0.000433104127193433,0.0004254850637671684,0.0004181093870234756,0.00041097397942598674,0.00040407582247348195,0.0003974119960598668,0.0003909796778584357,0.0003847761427246202,0.0003787987621252653,0.00037304500358689013,0.00036751243016837354,0.00036219869995460924,0.00035710156557347897,0.00035221887373677527,0.00034754856480175705,0.0003430886723559748,0.00033883732282742607,0.00033479273511480626,0.0003309532202421493,0.00032731718103724133,0.0003238831118315792,0.0003206495981868257,0.0003176153166411337,0.0003147790344808672,0.00031213960953703143,0.0003096959900022733,0.00030744721427657454,0.00030539241083046495,0.0003035307980976988,0.00030186168438957675,0.00030038446783352615,0.0002990986363356936,0.00029800376756871846,0.00029709952898307815,0.00029638567784303835,0.0002958620612868411,0.00029552861641276434,0.00029538537038774,0.0002954324405815417,0.00029567003472753123,0.0002960984511060534,0.00029671807875255446,0.00029752939769273415,0.0002985329792013665],"markLine":{"data":[],"lineStyle":{}},"type":"line"}],"theme":{"geo":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"parallel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"markPoint":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}},"emphasis":{"textStyle":{"color":"#eeeeee"}}}},"visualMap":{"color":["#e01f54","#e7dbc3"]},"funnel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"bar":{"itemStyle":{"normal":{"barBorderColor":"#ccc","barBorderWidth":0},"emphasis":{"barBorderColor":"#ccc","barBorderWidth":0}}},"map":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"scatter":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"pie":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"graph":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}}},"symbolSize":4,"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"}},"smooth":false,"symbol":"emptyCircle","color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"lineStyle":{"normal":{"color":"#aaaaaa","width":1}}},"backgroundColor":"rgba(0,0,0,0)","line":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"candlestick":{"itemStyle":{"normal":{"borderColor0":"#b8d2c7","color":"#e01f54","borderColor":"#f5e8c8","borderWidth":1,"color0":"#001852"}}},"sankey":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"valueAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"toolbox":{"iconStyle":{"normal":{"borderColor":"#999999"},"emphasis":{"borderColor":"#666666"}}},"categoryAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"tooltip":{"axisPointer":{"crossStyle":{"color":"#cccccc","width":1},"lineStyle":{"color":"#cccccc","width":1}}},"timeline":{"label":{"normal":{"textStyle":{"color":"#293c55"}},"emphasis":{"textStyle":{"color":"#293c55"}}},"controlStyle":{"normal":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5},"emphasis":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5}},"checkpointStyle":{"color":"#e43c59","borderColor":"rgba(194,53,49,0.5)"},"itemStyle":{"normal":{"color":"#293c55","borderWidth":1},"emphasis":{"color":"#a9334c"}},"lineStyle":{"color":"#293c55","width":1}},"radar":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"logAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"textStyle":{},"gauge":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"boxplot":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"title":{"textStyle":{"color":"#333333"},"subtextStyle":{"color":"#aaaaaa"}},"dataZoom":{"dataBackgroundColor":"rgba(47,69,84,0.3)","textStyle":{"color":"#333333"},"handleSize":"100%","handleColor":"#a7b7cc","fillerColor":"rgba(167,183,204,0.4)","backgroundColor":"rgba(47,69,84,0)"},"timeAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"legend":{"textStyle":{"color":"#333333"}}},"yAxis":[{"splitNumber":5,"axisLabel":{"show":true,"interval":"auto","rotate":0,"inside":false,"formatter":"{value}","margin":8},"scale":false,"gridIndex":0,"minInterval":0,"zlevel":0,"triggerEvent":false,"z":0,"inverse":false,"nameLocation":"middle","nameGap":50,"silent":true,"type":"value"}],"toolbox":{"feature":{},"orient":"vertical","itemSize":15,"height":"auto","zlevel":0,"z":2,"itemGap":20,"right":"auto","top":"center","width":"auto","show":false,"showTitle":true},"ec_width":800,"ec_height":400,"tooltip":{"triggerOn":"mousemove","enterable":true,"borderColor":"#333","transitionDuration":0.4,"hideDelay":100,"padding":5,"showDelay":0,"borderWidth":0,"showContent":true,"backgroundColor":"rgba(50,50,50,0.7)","trigger":"item","alwaysShowContent":false,"confine":false,"show":true},"grid":[{"height":"auto","show":false,"width":"auto","backgroundColor":"transparent"}],"title":[{"left":"left","borderColor":"transparent","bottom":"auto","padding":5,"zlevel":0,"borderWidth":1,"target":"blank","z":2,"itemGap":5,"shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","subtarget":"blank","show":true}],"ec_renderer":"canvas"}
        );
</script>
