---
title: theme!
sidebar: mydoc_sidebar
permalink: /theme
---

The `theme!` function is a convenience around the `Theme` type, so that end-users don't need to reference `ec.theme` directly (though, nothing prevents users modifying the `EChart` chart instance). There are 15 pre-defined themes, originating from the [ECharts theme builder](http://echarts.baidu.com/theme-builder/):

`chalk`, `dark`, `essos`, `halloween`, `infographic`, `macarons`, `roma`, `purplepassion`, `roma`, `shine`, `vintage`, `walden`, `westeros`, `wonderland`, `grayscale`.

Currently, none of themes are exported, to avoid namespace pollution. To use a theme in your code, prepend `ECharts` to the theme name (see example below). Note that `theme!` is a slightly different use case than [`colorscheme!`](/colorscheme) in that `theme!` can change all the properties of the graph (similar to a style sheet), whereas `colorscheme` only changes the series colors (but not the background, axes, title, text, etc.)  

To define your own themes, you can either create a `Theme()` struct directly in Julia or use the ECharts theme builder to create the JSON for you. After creating the JSON, themes can be loaded by using code similar to what is in `theme.jl`.

## Method Signatures
{% highlight julia %}
theme!(ec::EChart, theme::Theme)
{% endhighlight %}

## Optional Arguments
{% highlight julia %}
None currently
{% endhighlight %}

### Examples
{% highlight julia %}
using ECharts, DataFrames, CSV
s_df = CSV.read(Pkg.dir("ECharts", "exampledata/streamdata.csv"), types=[String, Float64, String])
sg = streamgraph(s_df[:date], s_df[:value], s_df[:key], legend = true)
{% endhighlight %}


<div id="sg1" style="height:400px;width:800px;"></div>
<script type="text/javascript">

    // Initialize after dom ready
    var myChart = echarts.init(document.getElementById("sg1"), JSON.parse(roma()));

    // Load data into the ECharts instance
    myChart.setOption(
{"singleAxis":{"type":"time"},"ec_charttype":"streamgraph","series":[{"data":[["2013/01/08",0.1,"AR"],["2013/01/09",0.15,"AR"],["2013/01/10",0.35,"AR"],["2013/01/11",0.38,"AR"],["2013/01/12",0.22,"AR"],["2013/01/13",0.16,"AR"],["2013/01/14",0.07,"AR"],["2013/01/15",0.02,"AR"],["2013/01/16",0.17,"AR"],["2013/01/17",0.33,"AR"],["2013/01/18",0.4,"AR"],["2013/01/19",0.32,"AR"],["2013/01/20",0.26,"AR"],["2013/01/21",0.35,"AR"],["2013/01/22",0.4,"AR"],["2013/01/23",0.32,"AR"],["2013/01/24",0.26,"AR"],["2013/01/25",0.22,"AR"],["2013/01/26",0.16,"AR"],["2013/01/27",0.22,"AR"],["2013/01/28",0.1,"AR"],["2013/01/08",0.35,"DJ"],["2013/01/09",0.36,"DJ"],["2013/01/10",0.37,"DJ"],["2013/01/11",0.22,"DJ"],["2013/01/12",0.24,"DJ"],["2013/01/13",0.26,"DJ"],["2013/01/14",0.34,"DJ"],["2013/01/15",0.21,"DJ"],["2013/01/16",0.18,"DJ"],["2013/01/17",0.45,"DJ"],["2013/01/18",0.32,"DJ"],["2013/01/19",0.35,"DJ"],["2013/01/20",0.3,"DJ"],["2013/01/21",0.28,"DJ"],["2013/01/22",0.27,"DJ"],["2013/01/23",0.26,"DJ"],["2013/01/24",0.15,"DJ"],["2013/01/25",0.3,"DJ"],["2013/01/26",0.35,"DJ"],["2013/01/27",0.42,"DJ"],["2013/01/28",0.42,"DJ"],["2013/01/08",0.21,"MS"],["2013/01/09",0.25,"MS"],["2013/01/10",0.27,"MS"],["2013/01/11",0.23,"MS"],["2013/01/12",0.24,"MS"],["2013/01/13",0.21,"MS"],["2013/01/14",0.35,"MS"],["2013/01/15",0.39,"MS"],["2013/01/16",0.4,"MS"],["2013/01/17",0.36,"MS"],["2013/01/18",0.33,"MS"],["2013/01/19",0.43,"MS"],["2013/01/20",0.4,"MS"],["2013/01/21",0.34,"MS"],["2013/01/22",0.28,"MS"],["2013/01/23",0.26,"MS"],["2013/01/24",0.37,"MS"],["2013/01/25",0.41,"MS"],["2013/01/26",0.46,"MS"],["2013/01/27",0.47,"MS"],["2013/01/28",0.41,"MS"],["2013/01/08",0.1,"RC"],["2013/01/09",0.15,"RC"],["2013/01/10",0.35,"RC"],["2013/01/11",0.38,"RC"],["2013/01/12",0.22,"RC"],["2013/01/13",0.16,"RC"],["2013/01/14",0.07,"RC"],["2013/01/15",0.02,"RC"],["2013/01/16",0.17,"RC"],["2013/01/17",0.33,"RC"],["2013/01/18",0.4,"RC"],["2013/01/19",0.32,"RC"],["2013/01/20",0.26,"RC"],["2013/01/21",0.35,"RC"],["2013/01/22",0.4,"RC"],["2013/01/23",0.32,"RC"],["2013/01/24",0.26,"RC"],["2013/01/25",0.22,"RC"],["2013/01/26",0.16,"RC"],["2013/01/27",0.22,"RC"],["2013/01/28",0.1,"RC"],["2013/01/08",0.1,"CG"],["2013/01/09",0.15,"CG"],["2013/01/10",0.35,"CG"],["2013/01/11",0.38,"CG"],["2013/01/12",0.22,"CG"],["2013/01/13",0.16,"CG"],["2013/01/14",0.07,"CG"],["2013/01/15",0.02,"CG"],["2013/01/16",0.17,"CG"],["2013/01/17",0.33,"CG"],["2013/01/18",0.4,"CG"],["2013/01/19",0.32,"CG"],["2013/01/20",0.26,"CG"],["2013/01/21",0.35,"CG"],["2013/01/22",0.4,"CG"],["2013/01/23",0.32,"CG"],["2013/01/24",0.26,"CG"],["2013/01/25",0.22,"CG"],["2013/01/26",0.16,"CG"],["2013/01/27",0.22,"CG"],["2013/01/28",0.1,"CG"],["2013/01/08",0.1,"RI"],["2013/01/09",0.15,"RI"],["2013/01/10",0.35,"RI"],["2013/01/11",0.38,"RI"],["2013/01/12",0.22,"RI"],["2013/01/13",0.16,"RI"],["2013/01/14",0.07,"RI"],["2013/01/15",0.02,"RI"],["2013/01/16",0.17,"RI"],["2013/01/17",0.33,"RI"],["2013/01/18",0.4,"RI"],["2013/01/19",0.32,"RI"],["2013/01/20",0.26,"RI"],["2013/01/21",0.35,"RI"],["2013/01/22",0.4,"RI"],["2013/01/23",0.32,"RI"],["2013/01/24",0.26,"RI"],["2013/01/25",0.22,"RI"],["2013/01/26",0.16,"RI"],["2013/01/27",0.22,"RI"],["2013/01/28",0.1,"RI"]],"type":"themeRiver"}],"theme":{"geo":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"parallel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"markPoint":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}},"emphasis":{"textStyle":{"color":"#eeeeee"}}}},"visualMap":{"color":["#e01f54","#e7dbc3"]},"funnel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"bar":{"itemStyle":{"normal":{"barBorderColor":"#ccc","barBorderWidth":0},"emphasis":{"barBorderColor":"#ccc","barBorderWidth":0}}},"map":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(100,0,0)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(255,215,0,0.8)"}}},"scatter":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"pie":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"graph":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}}},"symbolSize":4,"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"}},"smooth":false,"symbol":"emptyCircle","color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"lineStyle":{"normal":{"color":"#aaaaaa","width":1}}},"backgroundColor":"rgba(0,0,0,0)","line":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"candlestick":{"itemStyle":{"normal":{"borderColor0":"#b8d2c7","color":"#e01f54","borderColor":"#f5e8c8","borderWidth":1,"color0":"#001852"}}},"sankey":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"valueAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"toolbox":{"iconStyle":{"normal":{"borderColor":"#999999"},"emphasis":{"borderColor":"#666666"}}},"categoryAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"tooltip":{"axisPointer":{"crossStyle":{"color":"#cccccc","width":1},"lineStyle":{"color":"#cccccc","width":1}}},"timeline":{"label":{"normal":{"textStyle":{"color":"#293c55"}},"emphasis":{"textStyle":{"color":"#293c55"}}},"controlStyle":{"normal":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5},"emphasis":{"color":"#293c55","borderColor":"#293c55","borderWidth":0.5}},"checkpointStyle":{"color":"#e43c59","borderColor":"rgba(194,53,49,0.5)"},"itemStyle":{"normal":{"color":"#293c55","borderWidth":1},"emphasis":{"color":"#a9334c"}},"lineStyle":{"color":"#293c55","width":1}},"radar":{"symbolSize":4,"itemStyle":{"normal":{"borderWidth":1}},"smooth":false,"symbol":"emptyCircle","lineStyle":{"normal":{"width":2}}},"logAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"textStyle":{},"gauge":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"boxplot":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"color":["#e01f54","#001852","#f5e8c8","#b8d2c7","#c6b38e","#a4d8c2","#f3d999","#d3758f","#dcc392","#2e4783","#82b6e9","#ff6347","#a092f1","#0a915d","#eaf889","#6699FF","#ff6666","#3cb371","#d5b158","#38b6b6"],"title":{"textStyle":{"color":"#333333"},"subtextStyle":{"color":"#aaaaaa"}},"dataZoom":{"dataBackgroundColor":"rgba(47,69,84,0.3)","textStyle":{"color":"#333333"},"handleSize":"100%","handleColor":"#a7b7cc","fillerColor":"rgba(167,183,204,0.4)","backgroundColor":"rgba(47,69,84,0)"},"timeAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#333"}},"axisLabel":{"textStyle":{"color":"#333"},"show":true},"splitLine":{"show":true,"lineStyle":{"color":["#ccc"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.3)","rgba(200,200,200,0.3)"]},"show":false},"axisTick":{"show":true,"lineStyle":{"color":"#333"}}},"legend":{"textStyle":{"color":"#333333"}}},"toolbox":{"feature":{},"orient":"vertical","itemSize":15,"height":"auto","zlevel":0,"z":2,"itemGap":20,"right":"auto","top":"center","width":"auto","show":false,"showTitle":true},"ec_width":800,"ec_height":400,"tooltip":{"triggerOn":"mousemove","enterable":true,"borderColor":"#333","transitionDuration":0.4,"hideDelay":100,"padding":5,"showDelay":0,"borderWidth":0,"showContent":true,"backgroundColor":"rgba(50,50,50,0.7)","trigger":"item","alwaysShowContent":false,"confine":false,"show":true},"grid":[{"height":"auto","show":false,"width":"auto","backgroundColor":"transparent"}],"title":[{"left":"left","borderColor":"transparent","bottom":"auto","padding":5,"zlevel":0,"borderWidth":1,"target":"blank","z":2,"itemGap":5,"shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","subtarget":"blank","show":true}],"ec_renderer":"canvas","legend":{"itemWidth":25,"data":["AR","DJ","MS","RC","CG","RI"],"borderColor":"transparent","orient":"horizontal","bottom":"auto","height":"auto","zlevel":0,"padding":5,"borderWidth":1,"inactiveColor":"#ccc","z":2,"align":"auto","itemGap":10,"itemHeight":14,"backgroundColor":"transparent","shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","width":"auto","selectedMode":true,"show":true}}        );
</script>

{% highlight julia %}
theme!(sg, ECharts.purplepassion)
{% endhighlight %}


<div id="sg2" style="height:400px;width:800px;"></div>
<script type="text/javascript">

    // Initialize after dom ready
    var myChart = echarts.init(document.getElementById("sg2"), JSON.parse(purplepassion()));

    // Load data into the ECharts instance
    myChart.setOption(
{"singleAxis":{"type":"time"},"ec_charttype":"streamgraph","series":[{"data":[["2013/01/08",0.1,"AR"],["2013/01/09",0.15,"AR"],["2013/01/10",0.35,"AR"],["2013/01/11",0.38,"AR"],["2013/01/12",0.22,"AR"],["2013/01/13",0.16,"AR"],["2013/01/14",0.07,"AR"],["2013/01/15",0.02,"AR"],["2013/01/16",0.17,"AR"],["2013/01/17",0.33,"AR"],["2013/01/18",0.4,"AR"],["2013/01/19",0.32,"AR"],["2013/01/20",0.26,"AR"],["2013/01/21",0.35,"AR"],["2013/01/22",0.4,"AR"],["2013/01/23",0.32,"AR"],["2013/01/24",0.26,"AR"],["2013/01/25",0.22,"AR"],["2013/01/26",0.16,"AR"],["2013/01/27",0.22,"AR"],["2013/01/28",0.1,"AR"],["2013/01/08",0.35,"DJ"],["2013/01/09",0.36,"DJ"],["2013/01/10",0.37,"DJ"],["2013/01/11",0.22,"DJ"],["2013/01/12",0.24,"DJ"],["2013/01/13",0.26,"DJ"],["2013/01/14",0.34,"DJ"],["2013/01/15",0.21,"DJ"],["2013/01/16",0.18,"DJ"],["2013/01/17",0.45,"DJ"],["2013/01/18",0.32,"DJ"],["2013/01/19",0.35,"DJ"],["2013/01/20",0.3,"DJ"],["2013/01/21",0.28,"DJ"],["2013/01/22",0.27,"DJ"],["2013/01/23",0.26,"DJ"],["2013/01/24",0.15,"DJ"],["2013/01/25",0.3,"DJ"],["2013/01/26",0.35,"DJ"],["2013/01/27",0.42,"DJ"],["2013/01/28",0.42,"DJ"],["2013/01/08",0.21,"MS"],["2013/01/09",0.25,"MS"],["2013/01/10",0.27,"MS"],["2013/01/11",0.23,"MS"],["2013/01/12",0.24,"MS"],["2013/01/13",0.21,"MS"],["2013/01/14",0.35,"MS"],["2013/01/15",0.39,"MS"],["2013/01/16",0.4,"MS"],["2013/01/17",0.36,"MS"],["2013/01/18",0.33,"MS"],["2013/01/19",0.43,"MS"],["2013/01/20",0.4,"MS"],["2013/01/21",0.34,"MS"],["2013/01/22",0.28,"MS"],["2013/01/23",0.26,"MS"],["2013/01/24",0.37,"MS"],["2013/01/25",0.41,"MS"],["2013/01/26",0.46,"MS"],["2013/01/27",0.47,"MS"],["2013/01/28",0.41,"MS"],["2013/01/08",0.1,"RC"],["2013/01/09",0.15,"RC"],["2013/01/10",0.35,"RC"],["2013/01/11",0.38,"RC"],["2013/01/12",0.22,"RC"],["2013/01/13",0.16,"RC"],["2013/01/14",0.07,"RC"],["2013/01/15",0.02,"RC"],["2013/01/16",0.17,"RC"],["2013/01/17",0.33,"RC"],["2013/01/18",0.4,"RC"],["2013/01/19",0.32,"RC"],["2013/01/20",0.26,"RC"],["2013/01/21",0.35,"RC"],["2013/01/22",0.4,"RC"],["2013/01/23",0.32,"RC"],["2013/01/24",0.26,"RC"],["2013/01/25",0.22,"RC"],["2013/01/26",0.16,"RC"],["2013/01/27",0.22,"RC"],["2013/01/28",0.1,"RC"],["2013/01/08",0.1,"CG"],["2013/01/09",0.15,"CG"],["2013/01/10",0.35,"CG"],["2013/01/11",0.38,"CG"],["2013/01/12",0.22,"CG"],["2013/01/13",0.16,"CG"],["2013/01/14",0.07,"CG"],["2013/01/15",0.02,"CG"],["2013/01/16",0.17,"CG"],["2013/01/17",0.33,"CG"],["2013/01/18",0.4,"CG"],["2013/01/19",0.32,"CG"],["2013/01/20",0.26,"CG"],["2013/01/21",0.35,"CG"],["2013/01/22",0.4,"CG"],["2013/01/23",0.32,"CG"],["2013/01/24",0.26,"CG"],["2013/01/25",0.22,"CG"],["2013/01/26",0.16,"CG"],["2013/01/27",0.22,"CG"],["2013/01/28",0.1,"CG"],["2013/01/08",0.1,"RI"],["2013/01/09",0.15,"RI"],["2013/01/10",0.35,"RI"],["2013/01/11",0.38,"RI"],["2013/01/12",0.22,"RI"],["2013/01/13",0.16,"RI"],["2013/01/14",0.07,"RI"],["2013/01/15",0.02,"RI"],["2013/01/16",0.17,"RI"],["2013/01/17",0.33,"RI"],["2013/01/18",0.4,"RI"],["2013/01/19",0.32,"RI"],["2013/01/20",0.26,"RI"],["2013/01/21",0.35,"RI"],["2013/01/22",0.4,"RI"],["2013/01/23",0.32,"RI"],["2013/01/24",0.26,"RI"],["2013/01/25",0.22,"RI"],["2013/01/26",0.16,"RI"],["2013/01/27",0.22,"RI"],["2013/01/28",0.1,"RI"]],"type":"themeRiver"}],"theme":{"geo":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(255,255,255)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(224,152,199,1)"}}},"parallel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"markPoint":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}},"emphasis":{"textStyle":{"color":"#eeeeee"}}}},"visualMap":{"color":["#8a7ca8","#e098c7","#cceffa"]},"funnel":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"bar":{"itemStyle":{"normal":{"barBorderColor":"#ccc","barBorderWidth":0},"emphasis":{"barBorderColor":"#ccc","barBorderWidth":0}}},"map":{"label":{"normal":{"textStyle":{"color":"#000000"}},"emphasis":{"textStyle":{"color":"rgb(255,255,255)"}}},"itemStyle":{"normal":{"borderColor":"#444444","borderWidth":0.5,"areaColor":"#eeeeee"},"emphasis":{"borderColor":"#444444","borderWidth":1,"areaColor":"rgba(224,152,199,1)"}}},"scatter":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"pie":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"graph":{"label":{"normal":{"textStyle":{"color":"#eeeeee"}}},"symbolSize":"7","itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"}},"smooth":true,"symbol":"circle","color":["#9b8bba","#e098c7","#8fd3e8","#71669e","#cc70af","#7cb4cc"],"lineStyle":{"normal":{"color":"#aaaaaa","width":1}}},"backgroundColor":"rgba(91,92,110,1)","line":{"symbolSize":"7","itemStyle":{"normal":{"borderWidth":"2"}},"smooth":true,"symbol":"circle","lineStyle":{"normal":{"width":"3"}}},"candlestick":{"itemStyle":{"normal":{"borderColor0":"#8fd3e8","color":"#e098c7","borderColor":"#e098c7","borderWidth":"2","color0":"transparent"}}},"sankey":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"valueAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#cccccc"}},"axisLabel":{"textStyle":{"color":"#cccccc"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#eeeeee","#333333"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.05)","rgba(200,200,200,0.02)"]},"show":true},"axisTick":{"show":false,"lineStyle":{"color":"#333"}}},"toolbox":{"iconStyle":{"normal":{"borderColor":"#999999"},"emphasis":{"borderColor":"#666666"}}},"categoryAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#cccccc"}},"axisLabel":{"textStyle":{"color":"#cccccc"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#eeeeee","#333333"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.05)","rgba(200,200,200,0.02)"]},"show":true},"axisTick":{"show":false,"lineStyle":{"color":"#333"}}},"tooltip":{"axisPointer":{"crossStyle":{"color":"#cccccc","width":1},"lineStyle":{"color":"#cccccc","width":1}}},"timeline":{"label":{"normal":{"textStyle":{"color":"#8fd3e8"}},"emphasis":{"textStyle":{"color":"#8fd3e8"}}},"controlStyle":{"normal":{"color":"#8fd3e8","borderColor":"#8fd3e8","borderWidth":0.5},"emphasis":{"color":"#8fd3e8","borderColor":"#8fd3e8","borderWidth":0.5}},"checkpointStyle":{"color":"#8fd3e8","borderColor":"rgba(138,124,168,0.37)"},"itemStyle":{"normal":{"color":"#8fd3e8","borderWidth":1},"emphasis":{"color":"#8fd3e8"}},"lineStyle":{"color":"#8fd3e8","width":1}},"radar":{"symbolSize":"7","itemStyle":{"normal":{"borderWidth":"2"}},"smooth":true,"symbol":"circle","lineStyle":{"normal":{"width":"3"}}},"logAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#cccccc"}},"axisLabel":{"textStyle":{"color":"#cccccc"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#eeeeee","#333333"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.05)","rgba(200,200,200,0.02)"]},"show":true},"axisTick":{"show":false,"lineStyle":{"color":"#333"}}},"textStyle":{},"gauge":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"boxplot":{"itemStyle":{"normal":{"borderWidth":0,"borderColor":"#ccc"},"emphasis":{"borderWidth":0,"borderColor":"#ccc"}}},"color":["#9b8bba","#e098c7","#8fd3e8","#71669e","#cc70af","#7cb4cc"],"title":{"textStyle":{"color":"#ffffff"},"subtextStyle":{"color":"#cccccc"}},"dataZoom":{"backgroundColor":"rgba(0,0,0,0)","textStyle":{"color":"#333333"},"handleSize":"100%","handleColor":"#a7b7cc","fillerColor":"rgba(167,183,204,0.4)","dataBackgroundColor":"rgba(255,255,255,0.3)"},"timeAxis":{"axisLine":{"show":true,"lineStyle":{"color":"#cccccc"}},"axisLabel":{"textStyle":{"color":"#cccccc"},"show":true},"splitLine":{"show":false,"lineStyle":{"color":["#eeeeee","#333333"]}},"splitArea":{"areaStyle":{"color":["rgba(250,250,250,0.05)","rgba(200,200,200,0.02)"]},"show":true},"axisTick":{"show":false,"lineStyle":{"color":"#333"}}},"legend":{"textStyle":{"color":"#cccccc"}}},"toolbox":{"feature":{},"orient":"vertical","itemSize":15,"height":"auto","zlevel":0,"z":2,"itemGap":20,"right":"auto","top":"center","width":"auto","show":false,"showTitle":true},"ec_width":800,"ec_height":400,"tooltip":{"triggerOn":"mousemove","enterable":true,"borderColor":"#333","transitionDuration":0.4,"hideDelay":100,"padding":5,"showDelay":0,"borderWidth":0,"showContent":true,"backgroundColor":"rgba(50,50,50,0.7)","trigger":"item","alwaysShowContent":false,"confine":false,"show":true},"grid":[{"height":"auto","show":false,"width":"auto","backgroundColor":"transparent"}],"title":[{"left":"left","borderColor":"transparent","bottom":"auto","padding":5,"zlevel":0,"borderWidth":1,"target":"blank","z":2,"itemGap":5,"shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","subtarget":"blank","show":true}],"ec_renderer":"canvas","legend":{"itemWidth":25,"data":["AR","DJ","MS","RC","CG","RI"],"borderColor":"transparent","orient":"horizontal","bottom":"auto","height":"auto","zlevel":0,"padding":5,"borderWidth":1,"inactiveColor":"#ccc","z":2,"align":"auto","itemGap":10,"itemHeight":14,"backgroundColor":"transparent","shadowOffsetY":0,"shadowOffsetX":0,"right":"auto","top":"auto","width":"auto","selectedMode":true,"show":true}}        );
</script>
